@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed.h,v 1.29.6.5 2004/10/30 18:14:08 chpe Exp $
+ *  $Id: ephy-embed.h,v 1.34 2004/05/01 20:46:59 chpe Exp $
  */
 
 #ifndef EPHY_EMBED_H
@@ -39,8 +39,8 @@ G_BEGIN_DECLS
 
 #define EPHY_TYPE_EMBED_CHROME_MASK     (ephy_embed_chrome_get_type ())
 
-typedef struct EphyEmbed	EphyEmbed;
-typedef struct EphyEmbedIface	EphyEmbedIface;
+typedef struct _EphyEmbed	EphyEmbed; /* dummy typedef */
+typedef struct _EphyEmbedIface	EphyEmbedIface;
 
 typedef enum
 {
@@ -76,6 +76,43 @@ typedef enum
 	EMBED_RELOAD_FORCE	= 1 << 1
 } EmbedReloadFlags;
 
+typedef struct
+{
+	gboolean print_to_file;
+	char *printer;
+	char *file;
+	char *paper;
+	int top_margin;
+	int bottom_margin;
+	int left_margin;
+	int right_margin;
+	int pages;
+	int from_page;
+	int to_page;
+	int frame_type;
+	int orientation;
+	gboolean print_color;
+	gboolean preview;
+
+	/*
+	 * &T - title
+	 * &U - Document URL
+	 * &D - Date/Time
+	 * &P - Page Number
+	 * &PT - Page Number with total Number of Pages (example: 1 of 34)
+	 *
+	 * So, if headerLeftStr = "&T" the title and the document URL
+	 * will be printed out on the top left-hand side of each page.
+	 */
+	char *header_left_string;
+	char *header_center_string;
+	char *header_right_string;
+	char *footer_left_string;
+	char *footer_center_string;
+	char *footer_right_string;
+}
+EmbedPrintInfo;
+
 typedef enum
 {
 	PRINTPREVIEW_GOTO_PAGENUM	= 0,
@@ -95,7 +132,7 @@ typedef enum
 	STATE_IS_SECURE_HIGH
 } EmbedSecurityLevel;
 
-struct EphyEmbedIface
+struct _EphyEmbedIface
 {
 	GTypeInterface base_iface;
 
@@ -134,8 +171,6 @@ struct EphyEmbedIface
 					 EmbedSecurityLevel level);
 	void	 (* zoom_change)	(EphyEmbed *embed,
 					 float new_zoom);
-	gboolean (* modal_alert)	(EphyEmbed *embed);
-	void	 (* modal_alert_closed)	(EphyEmbed *embed);
 
 	/* Methods  */
 	void		   (* load_url)			(EphyEmbed *embed,
@@ -168,22 +203,23 @@ struct EphyEmbedIface
 	void		   (* get_security_level)	(EphyEmbed *embed,
 						  	 EmbedSecurityLevel *level,
 						  	 char **description);
-	void		   (* zoom_set)			(EphyEmbed *embed,
+	void		   (* set_zoom)			(EphyEmbed *embed,
 							 float zoom,
 							 gboolean reflow);
-	float		   (* zoom_get)			(EphyEmbed *embed);
+	float		   (* get_zoom)			(EphyEmbed *embed);
 	void		   (* find_set_properties)	(EphyEmbed *embed,
-							 char *search_string,
+							 const char *search_string,
 							 gboolean case_sensitive,
 							 gboolean wrap_around);
 	gboolean	   (* find_next)		(EphyEmbed *embed,
 							 gboolean backwards);
+	char *		   (* get_encoding)		(EphyEmbed *embed);
+	gboolean	   (* has_automatic_encoding)	(EphyEmbed *embed);
 	void		   (* set_encoding)		(EphyEmbed *embed,
 							 const char *encoding);
-	EphyEncodingInfo * (* get_encoding_info)	(EphyEmbed *embed);
-	void		   (* print)			(EphyEmbed *embed);
-	void		   (* set_print_preview_mode)	(EphyEmbed *embed,
-							 gboolean mode);
+	void		   (* print)			(EphyEmbed *embed,
+							 EmbedPrintInfo *info);
+	void		   (* print_preview_close)	(EphyEmbed *embed);
 	int		   (* print_preview_n_pages)	(EphyEmbed *embed);
 	void		   (* print_preview_navigate)	(EphyEmbed *embed,
 							 EmbedPrintPreviewNavType type,
@@ -247,15 +283,15 @@ void		  ephy_embed_get_security_level		(EphyEmbed *embed,
 						 	 char **description);
 
 /* Zoom */
-void		  ephy_embed_zoom_set			(EphyEmbed *embed,
+void		  ephy_embed_set_zoom			(EphyEmbed *embed,
 							 float zoom,
 							 gboolean reflow);
 
-float		  ephy_embed_zoom_get			(EphyEmbed *embed);
+float		  ephy_embed_get_zoom			(EphyEmbed *embed);
 
 /* Find */
 void		  ephy_embed_find_set_properties	(EphyEmbed *embed,
-							 char *search_string,
+							 const char *search_string,
 							 gboolean case_sensitive,
 							 gboolean wrap_around);
 
@@ -263,16 +299,18 @@ gboolean	  ephy_embed_find_next			(EphyEmbed *embed,
 							 gboolean backwards);
 
 /* Encoding */
+char		 *ephy_embed_get_encoding		(EphyEmbed *embed);
+
+gboolean	  ephy_embed_has_automatic_encoding	(EphyEmbed *embed);
+
 void		  ephy_embed_set_encoding		(EphyEmbed *embed,
 							 const char *encoding);
 
-EphyEncodingInfo *ephy_embed_get_encoding_info		(EphyEmbed *embed);
-
 /* Print */
-void		  ephy_embed_print			(EphyEmbed *embed);
+void		  ephy_embed_print			(EphyEmbed *embed,
+							 EmbedPrintInfo *info);
 
-void		  ephy_embed_set_print_preview_mode	(EphyEmbed *embed,
-							 gboolean preview_mode);
+void		  ephy_embed_print_preview_close	(EphyEmbed *embed);
 
 int		  ephy_embed_print_preview_n_pages	(EphyEmbed *embed);
 
