@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-history.c,v 1.46 2004/02/29 18:03:55 chpe Exp $
+ *  $Id$
  */
 
 #ifdef HAVE_CONFIG_H
@@ -133,7 +133,7 @@ ephy_history_set_property (GObject *object,
 			   const GValue *value,
 			   GParamSpec *pspec)
 {
-	EphyHistory *history = EPHY_HISTORY (history);
+	EphyHistory *history = EPHY_HISTORY (object);
 
 	switch (prop_id)
 	{
@@ -149,7 +149,7 @@ ephy_history_get_property (GObject *object,
 			   GValue *value,
 			   GParamSpec *pspec)
 {
-	EphyHistory *history = EPHY_HISTORY (history);
+	EphyHistory *history = EPHY_HISTORY (object);
 
 	switch (prop_id)
 	{
@@ -482,7 +482,6 @@ ephy_history_init (EphyHistory *eb)
 
 	/* Pages */
 	eb->priv->pages = ephy_node_new_with_id (db, PAGES_NODE_ID);
-	ephy_node_ref (eb->priv->pages);
 	g_value_init (&value, G_TYPE_STRING);
 	g_value_set_string (&value, _("All"));
 	ephy_node_set_property (eb->priv->pages,
@@ -513,7 +512,6 @@ ephy_history_init (EphyHistory *eb)
 
 	/* Hosts */
 	eb->priv->hosts = ephy_node_new_with_id (db, HOSTS_NODE_ID);
-	ephy_node_ref (eb->priv->hosts);
 	ephy_node_signal_connect_object (eb->priv->hosts,
 					 EPHY_NODE_CHILD_ADDED,
 				         (EphyNodeCallback) hosts_added_cb,
