@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-permission-manager.h,v 1.6 2004/02/20 11:49:42 chpe Exp $
+ *  $Id: ephy-permission-manager.h,v 1.7 2004/03/23 17:31:40 adamh Exp $
  */
 
 #ifndef EPHY_PERMISSION_MANAGER_H
@@ -36,9 +36,6 @@ G_BEGIN_DECLS
 
 #define EPHY_TYPE_PERMISSION_INFO		(ephy_permission_info_get_type ())
 
-typedef struct EphyPermissionManager		EphyPermissionManager;
-typedef struct EphyPermissionManagerIface	EphyPermissionManagerIface;
-
 typedef enum
 {
 	EPT_COOKIE,
@@ -53,12 +50,17 @@ typedef enum
 	EPHY_PERMISSION_DEFAULT
 } EphyPermission;
 
-typedef struct
+typedef struct _EphyPermissionInfo		EphyPermissionInfo;
+
+typedef struct EphyPermissionManager		EphyPermissionManager;
+typedef struct EphyPermissionManagerIface	EphyPermissionManagerIface;
+
+struct _EphyPermissionInfo
 {
 	char *host;
 	EphyPermissionType type;
 	EphyPermission permission;
-} EphyPermissionInfo;
+};
 
 struct EphyPermissionManagerIface
 {
