@@ -18,31 +18,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ContentHandler.cpp,v 1.47.4.4 2004/05/07 13:55:32 chpe Exp $
+ *  $Id: ContentHandler.cpp,v 1.56 2004/05/08 20:11:17 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
-#include "ContentHandler.h"
-#include "MozillaPrivate.h"
-#include "MozDownload.h"
-
-#include "nsCOMPtr.h"
-#include "nsString.h"
-#include "nsIURL.h"
-#include "nsILocalFile.h"
-#include "nsIMIMEInfo.h"
-#include "nsIInterfaceRequestorUtils.h"
-
-#include "ephy-prefs.h"
-#include "eel-gconf-extensions.h"
-#include "ephy-embed-single.h"
-#include "ephy-embed-shell.h"
-#include "ephy-file-chooser.h"
-#include "ephy-debug.h"
-
 #include <gtk/gtkimage.h>
 #include <gtk/gtkhbox.h>
 #include <gtk/gtkvbox.h>
@@ -53,6 +35,24 @@
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <glib/gi18n.h>
 
+#include <nsIURL.h>
+#include <nsILocalFile.h>
+#include <nsIMIMEInfo.h>
+#include <nsIInterfaceRequestorUtils.h>
+#include "nsCExternalHandlerService.h"
+
+#include "ephy-prefs.h"
+#include "ephy-embed-single.h"
+#include "ephy-embed-shell.h"
+#include "ephy-file-chooser.h"
+#include "ephy-stock-icons.h"
+#include "ephy-debug.h"
+#include "eel-gconf-extensions.h"
+
+#include "ContentHandler.h"
+#include "MozillaPrivate.h"
+#include "MozDownload.h"
+
 class GContentHandler;
 
 NS_IMPL_ISUPPORTS1(GContentHandler, nsIHelperAppLauncherDialog)
@@ -82,15 +82,10 @@ GContentHandler::~GContentHandler()
 // begin nsIHelperAppLauncher impl
 ////////////////////////////////////////////////////////////////////////////////
 
-#if MOZILLA_SNAPSHOT > 9
 /* void show (in nsIHelperAppLauncher aLauncher, in nsISupports aContext); */
 NS_IMETHODIMP GContentHandler::Show(nsIHelperAppLauncher *aLauncher,
 				    nsISupports *aContext,
 				    PRBool aForced)
-#else
-NS_IMETHODIMP GContentHandler::Show(nsIHelperAppLauncher *aLauncher,
-				    nsISupports *aContext)
-#endif
 {
 	nsresult rv;
 	EphyEmbedSingle *single;
@@ -124,9 +119,7 @@ NS_IMETHODIMP GContentHandler::Show(nsIHelperAppLauncher *aLauncher,
 
 /* nsILocalFile promptForSaveToFile (in nsISupports aWindowContext, in wstring aDefaultFile, in wstring aSuggestedFileExtension); */
 NS_IMETHODIMP GContentHandler::PromptForSaveToFile(
-#if MOZILLA_SNAPSHOT > 10
-				    nsIHelperAppLauncher *aLauncher,
-#endif				    
+				    nsIHelperAppLauncher *aLauncher,			    
 				    nsISupports *aWindowContext,
 				    const PRUnichar *aDefaultFile,
 				    const PRUnichar *aSuggestedFileExtension,
@@ -138,7 +131,7 @@ NS_IMETHODIMP GContentHandler::PromptForSaveToFile(
 
 	if (mAction != CONTENT_ACTION_SAVEAS)
 	{
-		return BuildDownloadPath (NS_ConvertUCS2toUTF8 (aDefaultFile).get(),
+		return BuildDownloadPath (NS_ConvertUTF16toUTF8 (aDefaultFile).get(),
 					  _retval);
 	}
 
@@ -147,9 +140,10 @@ NS_IMETHODIMP GContentHandler::PromptForSaveToFile(
 
 	dialog = ephy_file_chooser_new (_("Save"), parentWindow,
 					GTK_FILE_CHOOSER_ACTION_SAVE,
-					CONF_STATE_SAVE_DIR);
+					CONF_STATE_SAVE_DIR,
+					EPHY_FILE_FILTER_ALL);
 	gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dialog),
-					   NS_ConvertUCS2toUTF8 (aDefaultFile).get());
+					   NS_ConvertUTF16toUTF8 (aDefaultFile).get());
 	response = gtk_dialog_run (GTK_DIALOG (dialog));
 
 	if (response == GTK_RESPONSE_ACCEPT)
@@ -174,15 +168,6 @@ NS_IMETHODIMP GContentHandler::PromptForSaveToFile(
 	}
 }
 
-#if MOZILLA_SNAPSHOT < 10
-/* void showProgressDialog (in nsIHelperAppLauncher aLauncher, in nsISupports aContext); */
-NS_METHOD GContentHandler::ShowProgressDialog(nsIHelperAppLauncher *aLauncher,
-					      nsISupports *aContext)
-{
-	return NS_ERROR_NOT_IMPLEMENTED;
-}
-#endif
-
 NS_METHOD GContentHandler::LaunchHelperApp (void)
 {
 	nsCOMPtr<nsIExternalHelperAppService> helperService;
@@ -248,17 +233,10 @@ NS_METHOD GContentHandler::Init (void)
 	rv = MIMEInfo->GetMIMEType (mMimeType);
 #endif
 
-#if MOZILLA_SNAPSHOT > 11
 	mLauncher->GetTargetFile (getter_AddRefs(mTempFile));
 
 	mLauncher->GetSource (getter_AddRefs(mUri));
 	NS_ENSURE_TRUE (mUri, NS_ERROR_FAILURE);
-#else
-	PRInt64 TimeDownloadStarted;
-	rv = mLauncher->GetDownloadInfo (getter_AddRefs(mUri),
-					&TimeDownloadStarted,
-					getter_AddRefs(mTempFile));
-#endif
 	
 	rv = mUri->GetSpec (mUrl);
 	rv = mUri->GetScheme (mScheme);
@@ -279,7 +257,7 @@ NS_METHOD GContentHandler::MIMEConfirmAction ()
 
 	action_label =  (mAction == CONTENT_ACTION_OPEN) ||
 			(mAction == CONTENT_ACTION_OPEN_TMP) ?
-			_("_Open") : _("_Download");
+			GTK_STOCK_OPEN : EPHY_STOCK_DOWNLOAD;
 
 	dialog = gtk_dialog_new_with_buttons
 		("", parentWindow, GTK_DIALOG_NO_SEPARATOR,
