@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ContentHandler.h,v 1.14.4.2 2004/05/07 13:55:32 chpe Exp $
+ *  $Id: ContentHandler.h,v 1.18 2004/05/28 20:19:36 chpe Exp $
  */
 
 #ifndef __ContentHandler_h
@@ -28,21 +28,17 @@
 #include "ephy-embed-shell.h"
 
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
-#include "nsIHelperAppLauncherDialog.h"
-#include "nsIExternalHelperAppService.h"
-#include "nsCExternalHandlerService.h"
-#include "nsIWebProgressListener.h"
 
-#include "nsString.h"
-#include "nsIURI.h"
-#include "nsILocalFile.h"
+#include <nsCOMPtr.h>
+#include <nsISupports.h>
+#include <nsIURI.h>
+#include <nsIFile.h>
 
-#include "nsCRT.h"
-#include "nsWeakReference.h"
+#include <nsIHelperAppLauncherDialog.h>
 
-#include "nsCOMPtr.h"
-#include "nsISupports.h"
-#include "nsError.h"
+#ifdef ALLOW_PRIVATE_STRINGS
+#include <nsString.h>
+#endif
 
 typedef enum
 {
