@@ -34,21 +34,26 @@
  * the provisions above, a recipient may use your version of this file under
  * the terms of any one of the NPL, the GPL or the LGPL.
  *
- * ***** END LICENSE BLOCK ***** */
+ * ***** END LICENSE BLOCK *****
+ *
+ * $Id: EphyAboutRedirector.cpp,v 1.8 2004/04/29 10:41:10 marco Exp $
+ */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
 #include "EphyAboutRedirector.h"
-#include "nsNetCID.h"
-#include "nsIIOService.h"
-#include "nsIServiceManager.h"
-#include "nsCOMPtr.h"
-#include "nsIURI.h"
-#include "nsXPIDLString.h"
-#include "nsString.h"
-#include "plstr.h"
+
+#include <nsNetCID.h>
+#include <nsIIOService.h>
+#include <nsIServiceManager.h>
+#include <nsCOMPtr.h>
+#include <nsIURI.h>
+
+#ifdef ALLOW_PRIVATE_STRINGS
+#include <nsString.h>
+#endif
 
 static NS_DEFINE_CID(kIOServiceCID, NS_IOSERVICE_CID);
 
@@ -78,7 +83,7 @@ EphyAboutRedirector::NewChannel(nsIURI *aURI, nsIChannel **result)
 
 	for (int i = 0; i< kRedirTotal; i++) 
 	{
-		if (!PL_strcasecmp(path.get(), kRedirMap[i].id))
+		if (strcmp(path.get(), kRedirMap[i].id) == 0)
 		{
 			nsCOMPtr<nsIChannel> tempChannel;
 			ioService->NewChannel(nsDependentCString(kRedirMap[i].url),
