@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyContentPolicy.cpp,v 1.1.4.4 2004/08/27 20:55:44 chpe Exp $
+ *  $Id: EphyContentPolicy.cpp,v 1.4 2004/05/14 16:45:06 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -30,7 +30,10 @@
 
 #include <nsCOMPtr.h>
 #include <nsIURI.h>
+
+#ifdef ALLOW_PRIVATE_STRINGS
 #include <nsString.h>
+#endif
 
 #define CONF_LOCKDOWN_DISABLE_UNSAFE_PROTOCOLS	"/apps/epiphany/lockdown/disable_unsafe_protocols"
 #define CONF_LOCKDOWN_ADDITIONAL_SAFE_PROTOCOLS	"/apps/epiphany/lockdown/additional_safe_protocols"
@@ -57,16 +60,12 @@ EphyContentPolicy::~EphyContentPolicy()
 	g_slist_free (mSafeProtocols);
 }
 
-#if MOZILLA_SNAPSHOT >= 20
+#if MOZILLA_SNAPSHOT >= 18
 NS_IMETHODIMP
 EphyContentPolicy::ShouldLoad(PRUint32 aContentType,
 			      nsIURI *aContentLocation,
 			      nsIURI *aRequestingLocation,
-#if MOZILLA_SNAPSHOT >= 20
-			      nsISupports *aContext,
-#else
 			      nsIDOMNode *aRequestingNode,
-#endif
 			      const nsACString &aMimeTypeGuess,
 			      nsISupports *aExtra,
 			      PRInt16 *aDecision)
@@ -105,11 +104,7 @@ NS_IMETHODIMP
 EphyContentPolicy::ShouldProcess(PRUint32 aContentType,
 			         nsIURI *aContentLocation,
 			         nsIURI *aRequestingLocation,
-#if MOZILLA_SNAPSHOT >= 20
-			         nsISupports *aContext,
-#else
 			         nsIDOMNode *aRequestingNode,
-#endif
 			         const nsACString &aMimeType,
 			         nsISupports *aExtra,
 			         PRInt16 *aDecision)
@@ -164,4 +159,4 @@ NS_IMETHODIMP EphyContentPolicy::ShouldProcess(PRInt32 contentType,
 	*_retval = PR_TRUE;
 	return NS_OK;
 }
-#endif /* MOZILLA_SNAPSHOT >= 20 */
+#endif /* MOZILLA_SNAPSHOT >= 18 */
