@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphySingle.cpp,v 1.5.4.1 2004/05/17 13:17:09 chpe Exp $
+ *  $Id: EphySingle.cpp,v 1.8 2004/05/17 13:16:19 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -27,13 +27,14 @@
 
 #include "ephy-debug.h"
 
-#include <nsString.h>
 #include <nsIURI.h>
 #include <nsIPermissionManager.h>
 #include <nsICookieManager.h>
 #include <nsIServiceManager.h>
-#if MOZILLA_SNAPSHOT > 9
 #include <nsICookie2.h>
+
+#ifdef ALLOW_PRIVATE_STRINGS
+#include <nsString.h>
 #endif
 
 NS_IMPL_ISUPPORTS1(EphySingle, nsIObserver)
@@ -245,23 +246,19 @@ mozilla_cookie_to_ephy_cookie (nsICookie *cookie)
 	cookie->GetExpires (&dateTime);
 	info->expires = dateTime;
 
-#if MOZILLA_SNAPSHOT > 9
 	nsCOMPtr<nsICookie2> cookie2 = do_QueryInterface (cookie);
-	if (cookie2)
+	NS_ENSURE_TRUE (cookie2, info);
+		
+	PRBool isSession;
+	cookie2->GetIsSession (&isSession);
+	info->is_session = isSession != PR_FALSE;
+		
+	if (!isSession)
 	{
-		
-		PRBool isSession;
-		cookie2->GetIsSession (&isSession);
-		info->is_session = isSession != PR_FALSE;
-		
-		if (!isSession)
-		{
-			PRInt64 expiry;
-			cookie2->GetExpiry (&expiry);
-			info->real_expires = expiry;
-		}
+		PRInt64 expiry;
+		cookie2->GetExpiry (&expiry);
+		info->real_expires = expiry;
 	}
-#endif
 
 	return info;
 }
@@ -272,7 +269,6 @@ mozilla_permission_to_ephy_permission (nsIPermission *perm)
 	EphyPermissionType type = (EphyPermissionType) 0;
 
 	nsresult result;
-#if MOZILLA_SNAPSHOT >= 10
 	nsCAutoString str;
 	result = perm->GetType(str);
 	NS_ENSURE_SUCCESS (result, NULL);
@@ -289,13 +285,6 @@ mozilla_permission_to_ephy_permission (nsIPermission *perm)
 	{
 		type = EPT_POPUP;
 	}		
-#else
-	PRUint32 num;
-	result = perm->GetType(&num);
-	NS_ENSURE_SUCCESS (result, NULL);
-
-	type = (EphyPermissionType) num;
-#endif
 
 	PRUint32 cap;
 	perm->GetCapability(&cap);
