@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000 Marco Pesenti Gritti
+ *  Copyright (C) 2000-2004 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,30 +15,31 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EventContext.h,v 1.7.4.2 2004/07/07 13:20:17 chpe Exp $
+ *  $Id: EventContext.h,v 1.10 2004/04/29 19:22:07 marco Exp $
  */
 
 #ifndef EVENT_CONTEXT_H
 #define EVENT_CONTEXT_H
 
-#include "nsIDOMMouseEvent.h"
-#include "nsIDOMKeyEvent.h"
-#include "nsIDOMEvent.h"
-#include "nsIDOMNode.h"
-#include "nsString.h"
-#include "nsIDOMHTMLAnchorElement.h"
-#include "nsIDOMNSHTMLElement.h"
-#include "nsIDOMHTMLAreaElement.h"
-#include "nsIDOMHTMLBodyElement.h"
-#include "nsIDOMElementCSSInlineStyle.h"
-#include "nsIDOMCSSStyleDeclaration.h"
-#include "nsIDOMDocument.h"
-#include "nsIDocument.h"
 #include "EphyBrowser.h"
 
 #include "ephy-embed.h"
 #include "mozilla-embed-event.h"
 
+#include <nsIDOMMouseEvent.h>
+#include <nsIDOMKeyEvent.h>
+#include <nsIDOMEvent.h>
+#include <nsIDOMNode.h>
+#include <nsIDOMHTMLAnchorElement.h>
+#include <nsIDOMHTMLAreaElement.h>
+#include <nsIDOMHTMLBodyElement.h>
+#include <nsIDOMDocument.h>
+
+#ifdef ALLOW_PRIVATE_API
+#include <nsIDocument.h>
+#include <nsString.h>
+#endif
+
 class EventContext
 {
 public:
@@ -56,7 +57,6 @@ private:
 	nsCOMPtr<nsIDOMDocument> mDOMDocument;
 
 	nsresult GatherTextUnder (nsIDOMNode* aNode, nsString& aResult);
-        nsresult Unescape (const nsAString &aEscaped, nsAString &aUnescaped);
 	nsresult ResolveBaseURL (nsIDocument *doc, const nsAString &relurl, nsACString &url);
 	nsresult ResolveDocumentURL (nsIDocument *doc, const nsAString &relurl, nsACString &url);
 	nsresult GetEventContext (nsIDOMEventTarget *EventTarget,
