@@ -16,6 +16,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: GtkNSSDialogs.cpp,v 1.13 2004/05/24 21:50:34 xan Exp $
  */
 
 /*
@@ -32,20 +34,23 @@
 
 #include "MozillaPrivate.h"
 
-#include "nsIX509Cert.h"
-#include "nsCOMPtr.h"
-#include "nsIServiceManager.h"
-#include "nsIInterfaceRequestor.h"
-#include "nsIInterfaceRequestorUtils.h"
-#include "nsIX509CertValidity.h"
-#include "nsIX509CertDB.h"
-#include "nsIASN1Object.h"
-#include "nsIASN1Sequence.h"
-#include "nsICRLInfo.h"
-#include "nsISimpleEnumerator.h"
-#include "nsIArray.h"
-#include "nsString.h"
-#include "nsReadableUtils.h"
+#include <nsCOMPtr.h>
+#include <nsIServiceManager.h>
+#include <nsIInterfaceRequestor.h>
+#include <nsIInterfaceRequestorUtils.h>
+#include <nsIX509Cert.h>
+#include <nsIX509CertValidity.h>
+#include <nsIX509CertDB.h>
+#include <nsIASN1Object.h>
+#include <nsIASN1Sequence.h>
+#include <nsICRLInfo.h>
+#include <nsISimpleEnumerator.h>
+#include <nsIArray.h>
+
+#ifdef ALLOW_PRIVATE_STRINGS
+#include <nsReadableUtils.h>
+#include <nsString.h>
+#endif
 
 #include <gconf/gconf-client.h>
 #include <gtk/gtkdialog.h>
@@ -69,16 +74,14 @@
 #include <gtk/gtktextbuffer.h>
 #include <gtk/gtktextview.h>
 #include <gtk/gtkprogressbar.h>
-
 #include <libgnome/gnome-i18n.h>
+#include <time.h>
 
 #include "GtkNSSDialogs.h"
 #include "ephy-file-helpers.h"
 #include "ephy-glade.h"
 #include "ephy-gui.h"
 
-#include <time.h>
-
 NS_DEFINE_CID (kX509CertCID, NS_IX509CERT_IID);
 NS_DEFINE_CID (kASN1ObjectCID, NS_IASN1OBJECT_IID);
 
@@ -291,7 +294,7 @@ GtkNSSDialogs::ConfirmMismatchDomain (nsIInterfaceRequestor *ctx,
                                         PromiseFlatCString(targetURL).get());
 
 	ttCommonName = g_strdup_printf ("\"<tt>%s</tt>\"", 
-                                         NS_ConvertUCS2toUTF8(commonName).get());
+                                         NS_ConvertUTF16toUTF8(commonName).get());
 
         first = g_strdup_printf (_("The site %s returned security information for "
 				   "%s. It is possible that someone is intercepting "
@@ -333,7 +336,7 @@ GtkNSSDialogs::ConfirmUnknownIssuer (nsIInterfaceRequestor *ctx,
 	cert->GetCommonName (commonName);
 
 	ttCommonName = g_strdup_printf ("\"<tt>%s</tt>\"", 
-					NS_ConvertUCS2toUTF8(commonName).get());
+					NS_ConvertUTF16toUTF8(commonName).get());
 
 	secondary = g_strdup_printf
 		           (_("Your browser was unable to trust %s. "
@@ -437,7 +440,7 @@ GtkNSSDialogs::ConfirmCertExpired (nsIInterfaceRequestor *ctx,
 	fdate = g_locale_to_utf8 (formattedDate, -1, NULL, NULL, NULL);
 
 	ttCommonName = g_strdup_printf ("\"<tt>%s</tt>\"", 
-                                        NS_ConvertUCS2toUTF8(commonName).get());
+                                        NS_ConvertUTF16toUTF8(commonName).get());
 
 	secondary = g_strdup_printf (text, ttCommonName, fdate);
 
@@ -483,7 +486,7 @@ GtkNSSDialogs::NotifyCrlNextupdate (nsIInterfaceRequestor *ctx,
 	cert->GetCommonName (commonName);
 
 	ttCommonName = g_strdup_printf ("\"<tt>%s</tt>\"", 
-					NS_ConvertUCS2toUTF8(commonName).get());
+					NS_ConvertUTF16toUTF8(commonName).get());
 
 	ttTargetUrl = g_strdup_printf ("\"<tt>%s</tt>\"", 
 				       PromiseFlatCString(targetURL).get());
@@ -545,7 +548,7 @@ GtkNSSDialogs::ConfirmDownloadCACert(nsIInterfaceRequestor *ctx,
 	nsAutoString commonName;
 	cert->GetCommonName (commonName);
 	ttCommonName = g_strdup_printf ("\"<tt>%s</tt>\"", 
-					 NS_ConvertUCS2toUTF8(commonName).get());
+					 NS_ConvertUTF16toUTF8(commonName).get());
 
 	tertiary = g_strdup_printf (_("Trust %s to identify:"), ttCommonName );
 	g_free (ttCommonName);
@@ -833,7 +836,7 @@ GtkNSSDialogs::SetPKCS12FilePassword(nsIInterfaceRequestor *ctx,
 	else
 	{
 		gchar * text = gtk_editable_get_chars (GTK_EDITABLE (entry1), 0, -1);
-		_password = NS_ConvertUTF8toUCS2 (text);
+		CopyUTF8toUTF16 (text, _password);
 		g_free (text);
 		*_retval = PR_TRUE;
 	}
@@ -893,7 +896,7 @@ GtkNSSDialogs::GetPKCS12FilePassword(nsIInterfaceRequestor *ctx,
 	else
 	{
 		gchar * text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
-		_password = NS_ConvertUTF8toUCS2 (text);
+		CopyUTF8toUTF16 (text, _password);
 		g_free (text);
 		*_retval = PR_TRUE;
 	}
@@ -962,13 +965,13 @@ GtkNSSDialogs::CrlImportStatusDialog(nsIInterfaceRequestor *ctx, nsICRLInfo *crl
 	rv = crl->GetNextUpdateLocale (nextUpdate);
 	if (NS_FAILED(rv)) return rv;
 
-	label = gtk_label_new (NS_ConvertUCS2toUTF8(org).get());
+	label = gtk_label_new (NS_ConvertUTF16toUTF8(org).get());
 	set_table_row (table, 0, _("Organization:"), label);
 
-	label = gtk_label_new (NS_ConvertUCS2toUTF8(orgUnit).get());
+	label = gtk_label_new (NS_ConvertUTF16toUTF8(orgUnit).get());
 	set_table_row (table, 1, _("Unit:"), label);
 
-	label = gtk_label_new (NS_ConvertUCS2toUTF8(nextUpdate).get());
+	label = gtk_label_new (NS_ConvertUTF16toUTF8(nextUpdate).get());
 	set_table_row (table, 2, _("Next Update:"), label);
 
 	gtk_box_pack_start (GTK_BOX (vbox), higgy_indent_widget (table), FALSE, FALSE, 0);
@@ -1004,7 +1007,7 @@ set_label_cert_attribute (GladeXML* gxml, const char* label_id, nsAutoString &va
 	{
 		gtk_label_set_use_markup (GTK_LABEL (label), FALSE);
 		gtk_label_set_text (GTK_LABEL (label),
-				    NS_ConvertUCS2toUTF8(value).get());
+				    NS_ConvertUTF16toUTF8(value).get());
 	}
 }
 
@@ -1042,7 +1045,7 @@ fill_cert_chain_tree (GtkTreeView *treeview, nsIArray *certChain)
 		if (!value.IsEmpty())
 		{
 			gtk_tree_store_set (GTK_TREE_STORE(model), &iter,
-					    0, NS_ConvertUCS2toUTF8(value).get(),
+					    0, NS_ConvertUTF16toUTF8(value).get(),
 					    1, nsCertP,
 					    -1);
 		}
@@ -1083,7 +1086,7 @@ add_asn1_object_to_tree(GtkTreeModel *model, nsIASN1Object *object, GtkTreeIter
 	gtk_tree_store_append (GTK_TREE_STORE (model), &iter, parent);
 
 	gtk_tree_store_set (GTK_TREE_STORE(model), &iter,
-			    0, NS_ConvertUCS2toUTF8(dispNameU).get(),
+			    0, NS_ConvertUTF16toUTF8(dispNameU).get(),
 			    1, object,
 			    -1);
 
@@ -1158,7 +1161,7 @@ field_tree_view_selection_changed_cb (GtkTreeSelection *selection,
 
 		object->GetDisplayValue(dispValU);
 		gtk_text_buffer_set_text (text_buffer, 
-					  NS_ConvertUCS2toUTF8(dispValU).get(),
+					  NS_ConvertUTF16toUTF8(dispValU).get(),
 					  -1);
 	}
 	else
@@ -1324,7 +1327,7 @@ GtkNSSDialogs::ViewCert(nsIInterfaceRequestor *ctx,
 		GtkWidget *indent;
 		for (PRUint32 i = 0 ; i < count ; i++)
 		{
-			const nsACString &msg = NS_ConvertUCS2toUTF8 (usage[i]);
+			const nsACString &msg = NS_ConvertUTF16toUTF8 (usage[i]);
 			GtkWidget *label = gtk_label_new(PromiseFlatCString(msg).get());
 			gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 			gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
