@@ -16,6 +16,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: GtkNSSKeyPairDialogs.cpp,v 1.9 2004/05/29 13:59:58 chpe Exp $
  */
 
 /*
@@ -41,12 +43,15 @@
 
 #include "MozillaPrivate.h"
 
-#include "nsIServiceManager.h"
-#include "nsIInterfaceRequestor.h"
-#include "nsIInterfaceRequestorUtils.h"
-#include "nsIKeygenThread.h"
+#include <nsIServiceManager.h>
+#include <nsIInterfaceRequestor.h>
+#include <nsIInterfaceRequestorUtils.h>
+#include <nsIKeygenThread.h>
+#include <nsIDOMWindow.h>
+
+#ifdef ALLOW_PRIVATE_API
 #include "nsIDOMWindowInternal.h"
-#include "nsIDOMWindow.h"
+#endif
 
 #include "gtk/gtkdialog.h"
 #include "gtk/gtkprogressbar.h"
@@ -86,7 +91,7 @@ public:
 	NS_DECL_ISUPPORTS
 	NS_DECL_NSIDOMWINDOWINTERNAL
 	NS_DECL_NSIDOMWINDOW
-#if MOZILLA_SNAPSHOT >= 17
+#if MOZILLA_SNAPSHOT >= 19
 	NS_DECL_NSIDOMWINDOW2
 #endif
 
@@ -96,7 +101,7 @@ public:
 	gboolean close_called;
 };
 
-#if MOZILLA_SNAPSHOT >= 17
+#if MOZILLA_SNAPSHOT >= 19
 NS_IMPL_ISUPPORTS3(KeyPairHelperWindow, nsIDOMWindowInternal, nsIDOMWindow, nsIDOMWindow2)
 #else
 NS_IMPL_ISUPPORTS2(KeyPairHelperWindow, nsIDOMWindowInternal, nsIDOMWindow)
@@ -244,7 +249,7 @@ NS_IMETHODIMP KeyPairHelperWindow::GetWindow(nsIDOMWindowInternal * *aWindow)
     MOZ_NOT_IMPLEMENTED
 }
 
-#if MOZILLA_SNAPSHOT >= 17
+#if MOZILLA_SNAPSHOT >= 19
 NS_IMETHODIMP KeyPairHelperWindow::GetWindowRoot(nsIDOMEventTarget * *aEvent)
 {
     MOZ_NOT_IMPLEMENTED
@@ -281,14 +286,6 @@ NS_IMETHODIMP KeyPairHelperWindow::GetContent(nsIDOMWindow * *aContent)
     MOZ_NOT_IMPLEMENTED
 }
 
-#if MOZILLA_SNAPSHOT < 12
-/* readonly attribute nsISidebar sidebar; */
-NS_IMETHODIMP KeyPairHelperWindow::GetSidebar(nsISidebar * *aSidebar)
-{
-    MOZ_NOT_IMPLEMENTED
-}
-#endif
-
 /* [noscript] readonly attribute nsIPrompt prompter; */
 NS_IMETHODIMP KeyPairHelperWindow::GetPrompter(nsIPrompt * *aPrompter)
 {
@@ -599,20 +596,6 @@ NS_IMETHODIMP KeyPairHelperWindow::UpdateCommands(const nsAString & action)
     MOZ_NOT_IMPLEMENTED
 }
 
-#if MOZILLA_SNAPSHOT <= 12
-/* DOMString escape (in DOMString str); */
-NS_IMETHODIMP KeyPairHelperWindow::Escape(const nsAString & str, nsAString & _retval)
-{
-    MOZ_NOT_IMPLEMENTED
-}
-
-/* DOMString unescape (in DOMString str); */
-NS_IMETHODIMP KeyPairHelperWindow::Unescape(const nsAString & str, nsAString & _retval)
-{
-    MOZ_NOT_IMPLEMENTED
-}
-#endif
-
 /* [noscript] boolean find (in DOMString str, in boolean caseSensitive, in boolean backwards, in boolean wrapAround, in boolean wholeWord, in boolean searchInFrames, in boolean showDialog); */
 NS_IMETHODIMP KeyPairHelperWindow::Find(const nsAString & str, PRBool caseSensitive, PRBool backwards, PRBool wrapAround, PRBool wholeWord, PRBool searchInFrames, PRBool showDialog, PRBool *_retval)
 {
