@@ -38,7 +38,7 @@
  *
  * ***** END LICENSE BLOCK *****
  *
- * $Id: MozDownload.cpp,v 1.31.4.3 2004/04/26 19:21:34 chpe Exp $
+ * $Id: MozDownload.cpp,v 1.40 2004/05/19 15:21:02 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -55,12 +55,11 @@
 #include <libgnomevfs/gnome-vfs-utils.h>
 #include <glib/gi18n.h>
 
-#include "nsIExternalHelperAppService.h"
-#include "nsDirectoryServiceDefs.h"
-#include "nsDirectoryServiceUtils.h"
-#include "nsIRequest.h"
-#include "nsIMIMEInfo.h"
-#include "netCore.h"
+#include <nsIFileURL.h>
+
+#ifdef ALLOW_PRIVATE_STRINGS
+#include "nsNetUtil.h"
+#endif
 
 const char* const persistContractID = "@mozilla.org/embedding/browser/nsWebBrowserPersist;1";
 
@@ -80,10 +79,18 @@ MozDownload::~MozDownload()
 	NS_ASSERTION (!mEphyDownload, "MozillaDownload still alive!");
 }
 
+#if MOZILLA_SNAPSHOT < 16
 NS_IMPL_ISUPPORTS2(MozDownload, nsIDownload, nsIWebProgressListener)
+#else
+NS_IMPL_ISUPPORTS3(MozDownload, nsIDownload, nsITransfer, nsIWebProgressListener)
+#endif
 
 NS_IMETHODIMP
+#if MOZILLA_SNAPSHOT < 16
 MozDownload::InitForEmbed (nsIURI *aSource, nsILocalFile *aTarget, const PRUnichar *aDisplayName,
+#else
+MozDownload::InitForEmbed (nsIURI *aSource, nsIURI *aTarget, const PRUnichar *aDisplayName,
+#endif
 		           nsIMIMEInfo *aMIMEInfo, PRInt64 startTime, nsIWebBrowserPersist *aPersist,
 		           MozillaEmbedPersist *aEmbedPersist, PRInt32 aMaxSize)
 {
@@ -92,13 +99,18 @@ MozDownload::InitForEmbed (nsIURI *aSource, nsILocalFile *aTarget, const PRUnich
 	return Init (aSource, aTarget, aDisplayName, aMIMEInfo, startTime, aPersist);
 }
 
-/* void init (in nsIURI aSource, in nsILocalFile aTarget, in wstring aDisplayName, in nsIMIMEInfo aMIMEInfo, in long long startTime, in nsIWebBrowserPersist aPersist); */
+/* void init (in nsIURI aSource, in nsIURI aTarget, in wstring aDisplayName, in nsIMIMEInfo aMIMEInfo, in long long startTime, in nsIWebBrowserPersist aPersist); */
+#if MOZILLA_SNAPSHOT < 16
 NS_IMETHODIMP
 MozDownload::Init(nsIURI *aSource, nsILocalFile *aTarget, const PRUnichar *aDisplayName,
-		   nsIMIMEInfo *aMIMEInfo, PRInt64 startTime, nsIWebBrowserPersist *aPersist)
+		  nsIMIMEInfo *aMIMEInfo, PRInt64 startTime, nsIWebBrowserPersist *aPersist)
+#else
+NS_IMETHODIMP
+MozDownload::Init(nsIURI *aSource, nsIURI *aTarget, const PRUnichar *aDisplayName,
+		  nsIMIMEInfo *aMIMEInfo, PRInt64 startTime, nsIWebBrowserPersist *aPersist)
+#endif
 {
 	PRBool addToView = PR_TRUE;
-	nsresult rv;
 
 	if (mEmbedPersist)
 	{
@@ -153,8 +165,13 @@ MozDownload::GetSource(nsIURI **aSource)
 	return NS_OK;
 }
 
+#if MOZILLA_SNAPSHOT < 16
 NS_IMETHODIMP
 MozDownload::GetTarget(nsILocalFile **aTarget)
+#else
+NS_IMETHODIMP
+MozDownload::GetTarget(nsIURI **aTarget)
+#endif
 {
 	NS_ENSURE_ARG_POINTER(aTarget);
 	NS_IF_ADDREF(*aTarget = mDestination);
@@ -162,6 +179,23 @@ MozDownload::GetTarget(nsILocalFile **aTarget)
 	return NS_OK;
 }
 
+#if MOZILLA_SNAPSHOT > 15
+NS_IMETHODIMP
+MozDownload::GetTargetFile (nsILocalFile** aTargetFile)
+{
+	nsresult rv;
+                                                                                                                              
+	nsCOMPtr<nsIFileURL> fileURL = do_QueryInterface(mDestination, &rv);
+	if (NS_FAILED(rv)) return rv;
+                                                                                                                              
+	nsCOMPtr<nsIFile> file;
+	rv = fileURL->GetFile(getter_AddRefs(file));
+	if (NS_SUCCEEDED(rv))
+		rv = CallQueryInterface(file, aTargetFile);
+	return rv;
+}
+#endif
+
 NS_IMETHODIMP
 MozDownload::GetPersist(nsIWebBrowserPersist **aPersist)
 {
@@ -313,8 +347,8 @@ MozDownload::OnStateChange (nsIWebProgress *aWebProgress, nsIRequest *aRequest,
 		else if (NS_SUCCEEDED (aStatus))
 		{
 			GnomeVFSMimeApplication *helperApp;
-			char *mimeType;	
-
+#if MOZILLA_SNAPSHOT < 18
+			char *mimeType;
 			rv = mMIMEInfo->GetMIMEType (&mimeType);
 			NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
 
@@ -323,17 +357,35 @@ MozDownload::OnStateChange (nsIWebProgress *aWebProgress, nsIRequest *aRequest,
 			PRUnichar *description;
 			mMIMEInfo->GetApplicationDescription (&description);
 
+			/* HACK we use the application description to decide
+			   if we have to open the saved file */
+			if ((strcmp (NS_ConvertUTF16toUTF8 (description).get(), "gnome-default") == 0) &&
+			    helperApp)
+#else
+			nsCAutoString mimeType;
+			rv = mMIMEInfo->GetMIMEType (mimeType);
+			NS_ENSURE_SUCCESS (rv, NS_ERROR_FAILURE);
+
+			helperApp = gnome_vfs_mime_get_default_application (mimeType.get()); 
+
+			nsAutoString description;
+			mMIMEInfo->GetApplicationDescription (description);
+
 			/* HACK we use the application description to decide
 			   if we have to open the saved file */
 			if ((strcmp (NS_ConvertUCS2toUTF8 (description).get(), "gnome-default") == 0) &&
 			    helperApp)
+#endif
 			{
 				GList *params = NULL;
 				char *param;
 				nsCAutoString aDest;
 
+#if MOZILLA_SNAPSHOT < 16
 				mDestination->GetNativePath (aDest);
-
+#else
+				mDestination->GetSpec (aDest);
+#endif
 				param = gnome_vfs_make_uri_canonical (aDest.get ());
 				params = g_list_append (params, param);
 				gnome_vfs_mime_application_launch (helperApp, params);
@@ -341,9 +393,10 @@ MozDownload::OnStateChange (nsIWebProgress *aWebProgress, nsIRequest *aRequest,
 
 				g_list_free (params);
 			}
-
+#if MOZILLA_SNAPSHOT < 16
 			nsMemory::Free (mimeType);
 			nsMemory::Free (description);
+#endif
 			gnome_vfs_mime_application_free (helperApp);
 		}
 	}
@@ -478,9 +531,18 @@ nsresult InitiateMozillaDownload (nsIDOMDocument *domDocument, nsIURI *sourceURI
 	nsAutoString fileDisplayName;
 	inDestFile->GetLeafName(fileDisplayName);
 
+	#if MOZILLA_SNAPSHOT >= 16
+	nsCOMPtr<nsIURI> destURI;
+	NS_NewFileURI (getter_AddRefs(destURI), inDestFile);
+	#endif
+
 	MozDownload *downloader = new MozDownload ();
 	/* dlListener attaches to its progress dialog here, which gains ownership */
+	#if MOZILLA_SNAPSHOT < 16
 	rv = downloader->InitForEmbed (inOriginalURI, inDestFile, fileDisplayName.get(),
+	#else
+	rv = downloader->InitForEmbed (inOriginalURI, destURI, fileDisplayName.get(),
+	#endif
 				       nsnull, timeNow, webPersist, embedPersist, aMaxSize);
 	NS_ENSURE_SUCCESS (rv, rv);
 
@@ -525,7 +587,9 @@ nsresult InitiateMozillaDownload (nsIDOMDocument *domDocument, nsIURI *sourceURI
 			nameMinusExt.Left(nameMinusExt, index);
 		}
 
-		nameMinusExt += NS_LITERAL_STRING (" Files");
+		nameMinusExt += NS_LITERAL_STRING (" ");
+		nameMinusExt += NS_ConvertUTF8toUTF16 (_("Files"));
+ 
 		filesFolder->SetLeafName(nameMinusExt);
 
 		rv = webPersist->SaveDocument (domDocument, inDestFile, filesFolder,
@@ -539,7 +603,7 @@ static char*
 GetFilePath (const char *filename)
 {
 	char *path = NULL;
-	char *download_dir, *converted_dp, *expanded, *tmp;
+	char *download_dir, *converted_dp, *expanded;
 
 	download_dir = eel_gconf_get_string (CONF_STATE_DOWNLOAD_DIR);
 
