@@ -36,7 +36,7 @@
  *
  * ***** END LICENSE BLOCK *****
  *
- * $Id: MozDownload.h,v 1.13.4.2 2004/05/28 20:22:44 chpe Exp $
+ * $Id: MozDownload.h,v 1.17 2004/05/28 20:21:04 chpe Exp $
  */
 
 #ifndef MozDownload_h__
@@ -47,23 +47,24 @@
 #endif
 
 #include "mozilla-embed-persist.h"
-#include "nsIDownload.h"
-#include "nsIWebProgressListener.h"
-#include "nsIHelperAppLauncherDialog.h"
-#include "nsIExternalHelperAppService.h"
-#include "nsIDOMDocument.h"
-
-#include "nsString.h"
-#include "nsIURI.h"
-#include "nsILocalFile.h"
-#include "nsIWebBrowserPersist.h"
-#include "nsIObserver.h"
-#include "nsIRequest.h"
-#include "nsIMIMEInfo.h"
-
 #include "downloader-view.h"
 #include "ephy-download.h"
 #include "ephy-embed-shell.h"
+
+#include <nsIDownload.h>
+#include <nsIWebProgressListener.h>
+#include <nsIDOMDocument.h>
+#include <nsIURI.h>
+#include <nsILocalFile.h>
+#include <nsIWebBrowserPersist.h>
+#include <nsIObserver.h>
+#include <nsIRequest.h>
+#include <nsIMIMEInfo.h>
+
+#ifdef ALLOW_PRIVATE_API
+#include <nsString.h>
+#endif
+
 #include <libgnomevfs/gnome-vfs-mime-handlers.h>
 
 /* MozDownload
