@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: MozRegisterComponents.cpp,v 1.21.4.2 2004/05/07 12:42:05 chpe Exp $
+ *  $Id: MozRegisterComponents.cpp,v 1.26 2004/05/01 20:46:59 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -28,7 +28,6 @@
 #include "GlobalHistory.h"
 #include "PrintingPromptService.h"
 #include "MozDownload.h"
-#include "ExternalProtocolService.h"
 #include "EphyAboutRedirector.h"
 #include "EphyContentPolicy.h"
 
@@ -58,10 +57,6 @@ NS_GENERIC_FACTORY_CONSTRUCTOR(MozGlobalHistory)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GPrintingPromptService)
 NS_GENERIC_FACTORY_CONSTRUCTOR(EphyContentPolicy)
 
-#if MOZILLA_SNAPSHOT < 12
-NS_GENERIC_FACTORY_CONSTRUCTOR(GExternalProtocolService)
-#endif
-
 #ifdef HAVE_MOZILLA_PSM
 NS_GENERIC_FACTORY_CONSTRUCTOR(GtkNSSClientAuthDialogs)
 NS_GENERIC_FACTORY_CONSTRUCTOR(GtkNSSDialogs)
@@ -85,14 +80,6 @@ RegisterContentPolicy(nsIComponentManager *aCompMgr, nsIFile *aPath,
 }
 
 static const nsModuleComponentInfo sAppComps[] = {
-#if MOZILLA_SNAPSHOT < 12
-	{
-		G_EXTERNALPROTOCOLSERVICE_CLASSNAME,
-		G_EXTERNALPROTOCOLSERVICE_CID,
-		NS_EXTERNALPROTOCOLSERVICE_CONTRACTID,
- 		GExternalProtocolServiceConstructor
-	},
-#endif
 	{
 		MOZ_DOWNLOAD_CLASSNAME,
 		MOZ_DOWNLOAD_CID,
