@@ -15,13 +15,16 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: MozillaPrivate.cpp,v 1.9.4.1 2004/05/19 15:11:32 chpe Exp $
+ *  $Id: MozillaPrivate.cpp,v 1.12 2004/05/23 01:06:34 marco Exp $
  */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
+#include "ephy-embed.h"
+#include "mozilla-embed.h"
+
 #include "MozillaPrivate.h"
 
 #include <nsIServiceManagerUtils.h>
@@ -29,11 +32,11 @@
 #include <nsIEmbeddingSiteWindow.h>
 #include <nsIWebBrowserChrome.h>
 #include <gtkmozembed.h>
-#include <nsReadableUtils.h>
-#include <nsString.h>
 
-#include "ephy-embed.h"
-#include "mozilla-embed.h"
+#ifdef ALLOW_PRIVATE_STRINGS
+#include "nsString.h"
+#include "nsReadableUtils.h"
+#endif
 
 GtkWidget *MozillaFindEmbed (nsIDOMWindow *aDOMWindow)
 {
@@ -107,21 +110,21 @@ NS_METHOD MozillaCollatePrintSettings (const EmbedPrintInfo *info,
 
         options->SetPrinterName(NS_LITERAL_STRING("PostScript/default").get());
 
-        options->SetHeaderStrLeft(NS_ConvertUTF8toUCS2(info->header_left_string).get());
+        options->SetHeaderStrLeft(NS_ConvertUTF8toUTF16(info->header_left_string).get());
 
-        options->SetHeaderStrCenter(NS_ConvertUTF8toUCS2(info->header_center_string).get());
+        options->SetHeaderStrCenter(NS_ConvertUTF8toUTF16(info->header_center_string).get());
 
-        options->SetHeaderStrRight(NS_ConvertUTF8toUCS2(info->header_right_string).get());
+        options->SetHeaderStrRight(NS_ConvertUTF8toUTF16(info->header_right_string).get());
 
-        options->SetFooterStrLeft(NS_ConvertUTF8toUCS2(info->footer_left_string).get());
+        options->SetFooterStrLeft(NS_ConvertUTF8toUTF16(info->footer_left_string).get());
 
-        options->SetFooterStrCenter(NS_ConvertUTF8toUCS2(info->footer_center_string).get());
+        options->SetFooterStrCenter(NS_ConvertUTF8toUTF16(info->footer_center_string).get());
 
-        options->SetFooterStrRight(NS_ConvertUTF8toUCS2(info->footer_right_string).get());
+        options->SetFooterStrRight(NS_ConvertUTF8toUTF16(info->footer_right_string).get());
 
-        options->SetToFileName (NS_ConvertUTF8toUCS2(info->file).get());
+        options->SetToFileName (NS_ConvertUTF8toUTF16(info->file).get());
 
-	options->SetPrintCommand (NS_ConvertUTF8toUCS2(info->printer).get());
+	options->SetPrintCommand (NS_ConvertUTF8toUTF16(info->printer).get());
 
 	/**
 	 * Work around a mozilla bug where paper size & orientation are ignored
@@ -140,7 +143,7 @@ NS_METHOD MozillaCollatePrintSettings (const EmbedPrintInfo *info,
 
 	/* native paper size formats. Our dialog does not support custom yet */
 	options->SetPaperSize (nsIPrintSettings::kPaperSizeNativeData);
-	options->SetPaperName (NS_ConvertUTF8toUCS2(info->paper).get());
+	options->SetPaperName (NS_ConvertUTF8toUTF16(info->paper).get());
 
         options->SetPrintInColor (info->print_color);
         options->SetOrientation (info->orientation);
