@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-embed.cpp,v 1.62.4.9 2004/07/24 10:34:47 chpe Exp $
+ *  $Id: mozilla-embed.cpp,v 1.72 2004/05/10 22:04:27 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -34,23 +34,30 @@
 #include "EventContext.h"
 
 #include <gtkmozembed.h>
-#include <nsIWindowWatcher.h>
 #include <nsIURI.h>
 #include <nsIURL.h>
-#include <nsNetUtil.h>
-#include <nsString.h>
 #include <nsIRequest.h>
 #include <nsIWebProgressListener.h>
-#include <nsITransportSecurityInfo.h>
 #include <nsIPrintOptions.h>
 #include <nsGfxCIID.h>
 
+#ifdef ALLOW_PRIVATE_API
+/* not sure about this one */
+#include <nsITransportSecurityInfo.h>
+#endif
+
+#ifdef ALLOW_PRIVATE_STRINGS
+#include <nsNetUtil.h>
+#include <nsString.h>
+#endif
+
 static void	mozilla_embed_class_init	(MozillaEmbedClass *klass);
 static void	mozilla_embed_init		(MozillaEmbed *gs);
 static void	mozilla_embed_destroy		(GtkObject *object);
 static void	mozilla_embed_finalize		(GObject *object);
 static void	ephy_embed_iface_init		(EphyEmbedIface *iface);
 
+static void mozilla_embed_connect_signals	(MozillaEmbed *membed);
 static void mozilla_embed_location_changed_cb	(GtkMozEmbed *embed,
 						 MozillaEmbed *membed);
 static void mozilla_embed_net_state_all_cb	(GtkMozEmbed *embed,
@@ -82,7 +89,7 @@ struct MozillaEmbedPrivate
 {
 	EphyBrowser *browser;
 	nsCOMPtr<nsIRequest> request;
-	guint security_state;
+	gint security_state;
 };
 
 #define WINDOWWATCHER_CONTRACTID "@mozilla.org/embedcomp/window-watcher;1"
@@ -190,14 +197,14 @@ impl_activate (EphyEmbed *embed)
 
 static void
 impl_find_set_properties (EphyEmbed *embed, 
-                          char *search_string,
+                          const char *search_string,
 	                  gboolean case_sensitive,
 			  gboolean wrap_around)
 {
 	MozillaEmbedPrivate *mpriv = MOZILLA_EMBED(embed)->priv;
 
 	mpriv->browser->FindSetProperties
-		((NS_ConvertUTF8toUCS2(search_string)).get(),
+		((NS_ConvertUTF8toUTF16(search_string)).get(),
 		 case_sensitive, wrap_around); 
 }
 
@@ -516,33 +523,20 @@ static void
 impl_reload (EphyEmbed *embed, 
              EmbedReloadFlags flags)
 {
-	/* Workaround for broken reload with frames, see mozilla bug
-	 * http://bugzilla.mozilla.org/show_bug.cgi?id=246392
-	 * Replace #if 0 with appropriate MOZILLA_CHECK_VERSION4 once the bug
-	 * has been fixed
-	 */
-	gboolean force;
+	guint32 mflags;
 
-	force = (flags == EMBED_RELOAD_FORCE);
-#if 0
-	guint mflags = 0;
+	mflags = GTK_MOZ_EMBED_FLAG_RELOADNORMAL;
 
-	if (force)
+	if (flags & EMBED_RELOAD_FORCE)
 	{
 		mflags = GTK_MOZ_EMBED_FLAG_RELOADBYPASSPROXYANDCACHE;
 	}
-
+	
 	gtk_moz_embed_reload (GTK_MOZ_EMBED(embed), mflags);
-#else
-	MozillaEmbedPrivate *mpriv = MOZILLA_EMBED (embed)->priv;
-
-	mpriv->browser->Reload (force ? (PRUint32) EphyBrowser::RELOAD_FORCE :
-					(PRUint32) EphyBrowser::RELOAD_NORMAL);
-#endif
 }
 
 static void
-impl_zoom_set (EphyEmbed *embed, 
+impl_set_zoom (EphyEmbed *embed, 
                float zoom, 
                gboolean reflow)
 {
@@ -563,7 +557,7 @@ impl_zoom_set (EphyEmbed *embed,
 }
 
 static float
-impl_zoom_get (EphyEmbed *embed)
+impl_get_zoom (EphyEmbed *embed)
 {
 	MozillaEmbedPrivate *mpriv = MOZILLA_EMBED(embed)->priv;
 	float f;
@@ -615,7 +609,7 @@ impl_shistory_get_nth (EphyEmbed *embed,
 
 	if (title)
 	{
-		*aTitle = g_strdup (NS_ConvertUCS2toUTF8(title).get());
+		*aTitle = g_strdup (NS_ConvertUTF16toUTF8(title).get());
 
 		nsMemory::Free (title);
 	}
@@ -678,7 +672,7 @@ impl_get_security_level (EphyEmbed *embed,
 
 		if (tooltip)
 		{
-			*description = g_strdup (NS_ConvertUCS2toUTF8(tooltip).get());
+			*description = g_strdup (NS_ConvertUTF16toUTF8(tooltip).get());
 		}
 	}
 	
@@ -686,19 +680,39 @@ impl_get_security_level (EphyEmbed *embed,
 }
 
 static void
-impl_print (EphyEmbed *embed)
+impl_print (EphyEmbed *embed,
+            EmbedPrintInfo *info)
 {
 	MozillaEmbedPrivate *mpriv = MOZILLA_EMBED(embed)->priv;
- 
-	mpriv->browser->Print ();
+	nsresult result;
+
+        nsCOMPtr<nsIPrintSettings> options;
+        result = mpriv->browser->GetPrintSettings(getter_AddRefs(options));
+        if (NS_FAILED (result) || !options) return;
+
+	/* work around mozilla bug which borks when printing selection without having one */
+	if (info->pages == 2 && ephy_command_manager_can_do_command
+		(EPHY_COMMAND_MANAGER (embed), "cmd_copy") == FALSE)
+	{
+		info->pages = 0;
+	}
+
+	MozillaCollatePrintSettings(info, options);
+
+        options->SetPrintSilent (PR_TRUE);
+
+	result = mpriv->browser->Print(options, info->preview);
+
+	/* Workaround for bug 125984 */
+        options->SetPrintSilent (PR_FALSE);
 }
 
 static void
-impl_set_print_preview_mode (EphyEmbed *embed, gboolean preview_mode)
+impl_print_preview_close (EphyEmbed *embed)
 {
 	MozillaEmbedPrivate *mpriv = MOZILLA_EMBED(embed)->priv;
 
-	mpriv->browser->SetPrintPreviewMode (preview_mode);
+	mpriv->browser->PrintPreviewClose();
 }
 
 static int
@@ -730,40 +744,56 @@ impl_set_encoding (EphyEmbed *embed,
 {
 	MozillaEmbedPrivate *mpriv = MOZILLA_EMBED(embed)->priv;
 	nsresult result;
+	nsCAutoString currEnc;
 
-	result = mpriv->browser->ForceEncoding (encoding);
+	g_return_if_fail (encoding != NULL);
+
+	result = mpriv->browser->GetEncoding (currEnc);
 	if (NS_FAILED (result)) return;
 
-	/* Workaround for broken reload with frames, see mozilla bug
-	 * http://bugzilla.mozilla.org/show_bug.cgi?id=246392
-	 * Replace #if 0 with appropriate MOZILLA_CHECK_VERSION4 once the bug
-	 * has been fixed
-	 */
-#if 0
+	if (!currEnc.Equals(encoding) ||
+	    encoding[0] == '\0' && !ephy_embed_has_automatic_encoding (embed))
+	{
+		result = mpriv->browser->ForceEncoding (encoding);
+		if (NS_FAILED (result)) return;
+	}
+
 	gtk_moz_embed_reload (GTK_MOZ_EMBED (embed),
 			      GTK_MOZ_EMBED_FLAG_RELOADCHARSETCHANGE);
-#else
-	mpriv->browser->Reload (EphyBrowser::RELOAD_ENCODING_CHANGE);
-#endif
 }
 
-static EphyEncodingInfo *
-impl_get_encoding_info (EphyEmbed *embed)
+static char *
+impl_get_encoding (EphyEmbed *embed)
 {
 	MozillaEmbedPrivate *mpriv = MOZILLA_EMBED(embed)->priv;
 	nsresult result;
-	EphyEncodingInfo *info = NULL;
+	nsCAutoString encoding;
 
-	result = mpriv->browser->GetEncodingInfo (&info);
+	result = mpriv->browser->GetEncoding (encoding);
 
-	if (NS_FAILED (result))
+	if (NS_FAILED (result) || encoding.IsEmpty())
 	{
-		ephy_encoding_info_free (info);
-
 		return NULL;
 	}
 
-	return info;
+	return g_strdup (encoding.get());
+}
+
+static gboolean
+impl_has_automatic_encoding (EphyEmbed *embed)
+{
+	MozillaEmbedPrivate *mpriv = MOZILLA_EMBED(embed)->priv;
+	nsresult result;
+	nsCAutoString encoding;
+
+	result = mpriv->browser->GetForcedEncoding (encoding);
+
+	if (NS_FAILED (result) || encoding.IsEmpty())
+	{
+		return TRUE;
+	}
+
+	return FALSE;
 }
 
 static gboolean
@@ -1107,8 +1137,8 @@ ephy_embed_iface_init (EphyEmbedIface *iface)
 	iface->get_link_message = impl_get_link_message;
 	iface->get_js_status = impl_get_js_status;
 	iface->reload = impl_reload;
-	iface->zoom_set = impl_zoom_set;
-	iface->zoom_get = impl_zoom_get;
+	iface->set_zoom = impl_set_zoom;
+	iface->get_zoom = impl_get_zoom;
 	iface->shistory_n_items = impl_shistory_n_items;
 	iface->shistory_get_nth = impl_shistory_get_nth;
 	iface->shistory_get_pos = impl_shistory_get_pos;
@@ -1118,9 +1148,10 @@ ephy_embed_iface_init (EphyEmbedIface *iface)
 	iface->activate = impl_activate;
 	iface->find_set_properties = impl_find_set_properties;
 	iface->set_encoding = impl_set_encoding;
-	iface->get_encoding_info = impl_get_encoding_info;
+	iface->get_encoding = impl_get_encoding;
+	iface->has_automatic_encoding = impl_has_automatic_encoding;
 	iface->print = impl_print;
-	iface->set_print_preview_mode = impl_set_print_preview_mode;
+	iface->print_preview_close = impl_print_preview_close;
 	iface->print_preview_n_pages = impl_print_preview_n_pages;
 	iface->print_preview_navigate = impl_print_preview_navigate;
 	iface->has_modified_forms = impl_has_modified_forms;
