@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: egg-editable-toolbar.c,v 1.48.2.1 2004/04/03 09:34:32 chpe Exp $
+ *  $Id: egg-editable-toolbar.c,v 1.50 2004/04/16 22:32:22 marco Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -266,7 +266,7 @@ set_drag_cursor (GtkWidget *widget)
       GdkCursor *cursor;
       GdkPixbuf *pixbuf;
 
-      pixbuf = gdk_pixbuf_new_from_file (CURSOR_DIR "/art/hand-open.png", NULL);
+      pixbuf = gdk_pixbuf_new_from_file (CURSOR_DIR "/hand-open.png", NULL);
       cursor = gdk_cursor_new_from_pixbuf (gdk_display_get_default (),
 					   pixbuf, 12, 12);
       gdk_window_set_cursor (widget->window, cursor);
