@@ -1,6 +1,6 @@
 /*
  *  Copyright (C) 2003 Marco Pesenti Gritti
- *  Copyright (C) 2003 Christian Persch
+ *  Copyright (C) 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-file-chooser.c,v 1.9.4.1 2004/03/29 16:14:10 federico Exp $
+ *  $Id: ephy-file-chooser.c,v 1.12 2004/05/08 20:11:17 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -31,6 +31,7 @@
 
 #include <gtk/gtkstock.h>
 #include <libgnomevfs/gnome-vfs-utils.h>
+#include <glib/gi18n.h>
 
 #define EPHY_FILE_CHOOSER_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_FILE_CHOOSER, EphyFileChooserPrivate))
 
@@ -101,6 +102,26 @@ ephy_file_chooser_init (EphyFileChooser *dialog)
 	dialog->priv->persist_key = NULL;
 }
 
+static GObject *
+ephy_file_chooser_constructor (GType type,
+			       guint n_construct_properties,
+			       GObjectConstructParam *construct_params)
+
+{
+	GObject *object;
+	char *downloads_dir;
+
+	object = parent_class->constructor (type, n_construct_properties,
+					    construct_params);
+
+	downloads_dir = ephy_file_downloads_dir ();
+	gtk_file_chooser_add_shortcut_folder
+		(GTK_FILE_CHOOSER (object), downloads_dir, NULL);
+	g_free (downloads_dir);
+
+	return object;
+}
+
 static void
 ephy_file_chooser_finalize (GObject *object)
 {
@@ -154,6 +175,68 @@ ephy_file_chooser_get_persist_key (EphyFileChooser *dialog)
 	return dialog->priv->persist_key;
 }
 
+/* This function should really be in gtk+, see bug 142142 */
+
+GtkFileFilter *
+ephy_file_chooser_add_pattern_filter (EphyFileChooser *dialog,
+				      const char *title,
+				      const char *first_pattern,
+				      ...)
+{
+	GtkFileFilter *filth;
+	va_list args;
+	const char *pattern;
+
+	filth = gtk_file_filter_new ();
+
+	va_start (args, first_pattern);
+
+	pattern = first_pattern;
+	while (pattern != NULL)
+	{
+		gtk_file_filter_add_pattern (filth, pattern);
+		pattern = va_arg (args, const char *);
+	}
+	va_end (args);
+
+	gtk_file_filter_set_name (filth, title);
+
+	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), filth);
+
+	return filth;
+}
+
+/* This function should really be in gtk+, see bug 142142 */
+
+GtkFileFilter *
+ephy_file_chooser_add_mime_filter (EphyFileChooser *dialog,
+				   const char *title,
+				   const char *first_mimetype,
+				   ...)
+{
+	GtkFileFilter *filth;
+	va_list args;
+	const char *mimetype;
+
+	filth = gtk_file_filter_new ();
+
+	va_start (args, first_mimetype);
+
+	mimetype = first_mimetype;
+	while (mimetype != NULL)
+	{
+		gtk_file_filter_add_mime_type (filth, mimetype);
+		mimetype = va_arg (args, const char *);
+	}
+	va_end (args);
+
+	gtk_file_filter_set_name (filth, title);
+
+	gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), filth);
+
+	return filth;
+}
+
 static void
 ephy_file_chooser_set_property (GObject *object,
 				guint prop_id,
@@ -193,6 +276,7 @@ ephy_file_chooser_class_init (EphyFileChooserClass *klass)
 
 	parent_class = g_type_class_peek_parent (klass);
 
+	object_class->constructor = ephy_file_chooser_constructor;
 	object_class->finalize = ephy_file_chooser_finalize;
 	object_class->get_property = ephy_file_chooser_get_property;
 	object_class->set_property = ephy_file_chooser_set_property;
@@ -212,9 +296,13 @@ EphyFileChooser	*
 ephy_file_chooser_new (const char *title,
 		       GtkWidget *parent,
 		       GtkFileChooserAction action,
-		       const char *persist_key)
+		       const char *persist_key,
+		       EphyFileFilterDefault default_filter)
 {
 	EphyFileChooser *dialog;
+	GtkFileFilter *filter[EPHY_FILE_FILTER_LAST];
+
+	g_return_val_if_fail (default_filter >= 0 && default_filter <= EPHY_FILE_FILTER_LAST, NULL);
 
 	dialog = EPHY_FILE_CHOOSER (g_object_new (EPHY_TYPE_FILE_CHOOSER,
 						  "title", title,
@@ -253,6 +341,44 @@ ephy_file_chooser_new (const char *title,
 						 GTK_RESPONSE_ACCEPT);
 	}
 
+	if (default_filter != EPHY_FILE_FILTER_NONE)
+	{
+		filter[EPHY_FILE_FILTER_ALL_SUPPORTED] =
+			ephy_file_chooser_add_mime_filter
+				(dialog,
+				 _("All supported types"),
+				 "text/html",
+				 "application/xhtml+xml",
+				 "text/xml",
+				 "image/png",
+				 "image/jpeg",
+				 "image/gif",
+				 NULL);
+
+		filter[EPHY_FILE_FILTER_WEBPAGES] =
+			ephy_file_chooser_add_mime_filter
+				(dialog, _("Web pages"),
+				 "text/html",
+				 "application/xhtml+xml",
+				 "text/xml",
+				 NULL);
+
+		filter[EPHY_FILE_FILTER_IMAGES] =
+			ephy_file_chooser_add_mime_filter
+				(dialog, _("Images"),
+				 "image/png",
+				 "image/jpeg",
+				 "image/gif",
+				 NULL);
+
+		filter[EPHY_FILE_FILTER_ALL] =
+			ephy_file_chooser_add_pattern_filter
+				(dialog, _("All files"), "*", NULL);
+
+		gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (dialog),
+					     filter[default_filter]);
+	}
+
 	if (parent != NULL)
 	{
 		gtk_window_set_transient_for (GTK_WINDOW (dialog),
