@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-file-helpers.c,v 1.18.4.2 2004/07/22 09:29:42 chpe Exp $
+ *  $Id: ephy-file-helpers.c,v 1.19 2004/05/29 14:36:07 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -224,25 +224,17 @@ ephy_file_helpers_shutdown (void)
 	dot_dir = NULL;
 }
 
-gboolean
+void
 ephy_ensure_dir_exists (const char *dir)
 {
 	if (g_file_test (dir, G_FILE_TEST_IS_DIR) == FALSE)
 	{
 		if (g_file_test (dir, G_FILE_TEST_EXISTS) == TRUE)
-		{
-			g_warning (_("%s exists, please move it out of the way."), dir);
-			return FALSE;
-		}
+			g_error (_("%s exists, please move it out of the way."), dir);
 
 		if (mkdir (dir, 488) != 0)
-		{
-			g_warning (_("Failed to create directory %s."), dir);
-			return FALSE;
-		}
+			g_error (_("Failed to create directory %s."), dir);
 	}
-
-	return TRUE;
 }
 
 static void
