@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000 Marco Pesenti Gritti
+ *  Copyright (C) 2000, 2004 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -14,6 +14,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: ephy-glade.h,v 1.3 2004/02/21 19:58:05 chpe Exp $
  */
 
 #ifndef EPHY_GLADE_H
@@ -23,18 +25,19 @@
 #include <gtk/gtk.h>
 #include <glade/glade-xml.h>
 
+G_BEGIN_DECLS
+
 typedef struct
 {
         const gchar *name;
         GtkWidget **ptr;
 } WidgetLookup;
 
-G_BEGIN_DECLS
-
 GladeXML   *ephy_glade_widget_new	(const char *file,
 					 const char *widget_name,
 					 GtkWidget **root,
-					 gpointer data);
+					 gpointer data,
+					 const char *domain);
 
 G_END_DECLS
 
