@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-node.c,v 1.28 2003/12/16 17:29:40 marco Exp $
+ *  $Id: ephy-node.c,v 1.31 2004/04/09 16:59:36 adamh Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -50,6 +50,12 @@ typedef struct
 	guint index;
 } EphyNodeParent;
 
+typedef struct
+{
+	EphyNode *node;
+	guint property_id;
+} EphyNodeChange;
+
 struct EphyNode
 {
 	int ref_count;
@@ -106,8 +112,25 @@ callback (long id, EphyNodeSignalData *data, gpointer *dummy)
 		break;
 
 		case EPHY_NODE_CHILD_ADDED:
+		{
+			EphyNode *node;
+
+			node = va_arg (valist, EphyNode *);
+		
+			data->callback (data->node, node, data->data);
+		}
+		break;
+
 		case EPHY_NODE_CHILD_CHANGED:
-			data->callback (data->node, va_arg (valist, EphyNode *), data->data);
+		{
+			EphyNode *node;
+			guint property_id;
+
+			node = va_arg (valist, EphyNode *);
+			property_id = va_arg (valist, guint);
+		
+			data->callback (data->node, node, property_id, data->data);
+		}
 		break;
 
 		case EPHY_NODE_CHILD_REMOVED:
@@ -277,6 +300,8 @@ ephy_node_new (EphyNodeDb *db)
 
 	g_return_val_if_fail (EPHY_IS_NODE_DB (db), NULL);
 
+	if (ephy_node_db_is_immutable (db)) return NULL;
+
 	id = _ephy_node_db_new_id (db);
 
 	return ephy_node_new_with_id (db, id);
@@ -289,9 +314,11 @@ ephy_node_new_with_id (EphyNodeDb *db, gulong reserved_id)
 
 	g_return_val_if_fail (EPHY_IS_NODE_DB (db), NULL);
 
+	if (ephy_node_db_is_immutable (db)) return NULL;
+
 	node = g_new0 (EphyNode, 1);
 
-	node->ref_count = 0;
+	node->ref_count = 1;
 
 	node->id = reserved_id;
 
@@ -361,9 +388,10 @@ ephy_node_unref (EphyNode *node)
 static void
 child_changed (gulong id,
 	       EphyNodeParent *node_info,
-	       EphyNode *node)
+	       EphyNodeChange *change)
 {
-	ephy_node_emit_signal (node_info->node, EPHY_NODE_CHILD_CHANGED, node);
+	ephy_node_emit_signal (node_info->node, EPHY_NODE_CHILD_CHANGED,
+			       change->node, change->property_id);
 }
 
 static inline void
@@ -392,20 +420,25 @@ ephy_node_set_property (EphyNode *node,
 		        const GValue *value)
 {
 	GValue *new;
+	EphyNodeChange change;
 
 	g_return_if_fail (EPHY_IS_NODE (node));
 	g_return_if_fail (property_id >= 0);
 	g_return_if_fail (value != NULL);
 
+	if (ephy_node_db_is_immutable (node->db)) return;
+
 	new = g_new0 (GValue, 1);
 	g_value_init (new, G_VALUE_TYPE (value));
 	g_value_copy (value, new);
 
 	real_set_property (node, property_id, new);
 
+	change.node = node;
+	change.property_id = property_id;
 	g_hash_table_foreach (node->parents,
 			      (GHFunc) child_changed,
-			      node);
+			      &change);
 }
 
 gboolean
@@ -759,11 +792,13 @@ ephy_node_new_from_xml (EphyNodeDb *db, xmlNodePtr xml_node)
 	g_return_val_if_fail (EPHY_IS_NODE_DB (db), NULL);
 	g_return_val_if_fail (xml_node != NULL, NULL);
 
+	if (ephy_node_db_is_immutable (db)) return NULL; 
+
 	xml = xmlGetProp (xml_node, "id");
 	if (xml == NULL)
 		return NULL;
 	id = atol (xml);
-	g_free (xml);
+	xmlFree (xml);
 
 	node = ephy_node_new_with_id (db, id);
 
@@ -775,7 +810,7 @@ ephy_node_new_from_xml (EphyNodeDb *db, xmlNodePtr xml_node)
 			xml = xmlGetProp (xml_child, "id");
 			g_assert (xml != NULL);
 			parent_id = atol (xml);
-			g_free (xml);
+			xmlFree (xml);
 
 			parent = ephy_node_db_get_node_from_id (db, parent_id);
 
@@ -792,11 +827,11 @@ ephy_node_new_from_xml (EphyNodeDb *db, xmlNodePtr xml_node)
 
 			xml = xmlGetProp (xml_child, "id");
 			property_id = atoi (xml);
-			g_free (xml);
+			xmlFree (xml);
 
 			xml = xmlGetProp (xml_child, "value_type");
 			value_type = g_type_from_name (xml);
-			g_free (xml);
+			xmlFree (xml);
 
 			xml = xmlNodeGetContent (xml_child);
 			value = g_new0 (GValue, 1);
@@ -838,7 +873,7 @@ ephy_node_new_from_xml (EphyNodeDb *db, xmlNodePtr xml_node)
 
 			real_set_property (node, property_id, value);
 
-			g_free (xml);
+			xmlFree (xml);
 		}
 	}
 
@@ -852,6 +887,8 @@ ephy_node_add_child (EphyNode *node,
 		     EphyNode *child)
 {
 	g_return_if_fail (EPHY_IS_NODE (node));
+
+	if (ephy_node_db_is_immutable (node->db)) return;
 	
 	real_add_child (node, child);
 
@@ -864,6 +901,8 @@ ephy_node_remove_child (EphyNode *node,
 {
 	g_return_if_fail (EPHY_IS_NODE (node));
 
+	if (ephy_node_db_is_immutable (node->db)) return;
+
 	real_remove_child (node, child, TRUE, TRUE);
 }
 
@@ -906,6 +945,8 @@ ephy_node_sort_children (EphyNode *node,
 	GPtrArray *newkids;
 	int i, *new_order;
 
+	if (ephy_node_db_is_immutable (node->db)) return;
+
 	g_return_if_fail (EPHY_IS_NODE (node));
 	g_return_if_fail (compare_func != NULL);
 
@@ -953,6 +994,8 @@ ephy_node_reorder_children (EphyNode *node,
 	g_return_if_fail (EPHY_IS_NODE (node));
 	g_return_if_fail (new_order != NULL);
 
+	if (ephy_node_db_is_immutable (node->db)) return;
+
 	newkids = g_ptr_array_new ();
 	g_ptr_array_set_size (newkids, node->children->len);
 
