@@ -15,9 +15,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-node-view.c,v 1.36.4.1 2004/08/23 12:45:47 chpe Exp $
+ *  $Id: ephy-node-view.c,v 1.38 2004/03/18 19:59:34 xan Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include <gtk/gtktreeselection.h>
 #include <gtk/gtktreeviewcolumn.h>
 #include <gtk/gtkcellrenderertext.h>
@@ -89,6 +93,7 @@ enum
 	NODE_ACTIVATED,
 	NODE_SELECTED,
 	NODE_DROPPED,
+	SHOW_POPUP,
 	LAST_SIGNAL
 };
 
@@ -190,6 +195,15 @@ ephy_node_view_class_init (EphyNodeViewClass *klass)
 			      2,
 			      G_TYPE_POINTER,
 			      G_TYPE_POINTER);
+	ephy_node_view_signals[SHOW_POPUP] =
+		g_signal_new ("show_popup",
+			      G_OBJECT_CLASS_TYPE (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (EphyNodeViewClass, show_popup),
+			      NULL, NULL,
+			      g_cclosure_marshal_VOID__VOID,
+			      G_TYPE_NONE,
+			      0);
 
 	g_type_class_add_private (object_class, sizeof (EphyNodeViewPrivate));
 }
@@ -678,7 +692,7 @@ ephy_node_view_select_node_by_key (EphyNodeView *view, GdkEventKey *event)
 
 		string = g_utf8_casefold (g_value_get_string (&value), -1);
 		g_utf8_strncpy (string, string, 1);
-		found = (g_utf8_collate (string, event_string) >= 0);
+		found = (g_utf8_collate (string, event_string) == 0);
 
 		g_free (string);
 		g_value_unset (&value);
@@ -703,8 +717,15 @@ ephy_node_view_key_press_cb (GtkTreeView *treeview,
 			     GdkEventKey *event,
 			     EphyNodeView *view)
 {
-	if (view->priv->searchable_data_column != -1 &&
-	    gdk_keyval_to_unicode (event->keyval))
+	if ((event->state & GDK_SHIFT_MASK) &&
+	    (event->keyval == GDK_F10))
+	{
+		g_signal_emit (G_OBJECT (view), ephy_node_view_signals[SHOW_POPUP], 0);
+
+		return TRUE;
+	}
+	else if (view->priv->searchable_data_column != -1 &&
+		 gdk_keyval_to_unicode (event->keyval))
 	{
 		return ephy_node_view_select_node_by_key (view, event);
 	}
@@ -922,9 +943,7 @@ ephy_node_view_button_press_cb (GtkWidget *treeview,
 
 		if (event->button == 3)
 		{
-			gboolean retval;
-
-			g_signal_emit_by_name (view, "popup_menu", &retval);
+			g_signal_emit (G_OBJECT (view), ephy_node_view_signals[SHOW_POPUP], 0);
 		}
 		else if (event->button == 1)
 		{
