@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-bookmark-action.c,v 1.27 2004/02/11 14:38:55 marco Exp $
+ *  $Id: ephy-bookmark-action.c,v 1.31 2004/05/19 18:42:22 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -33,6 +33,8 @@
 #include "ephy-string.h"
 #include "ephy-debug.h"
 
+#include <string.h>
+
 #define MAX_LABEL_LENGTH 32
 
 static void ephy_bookmark_action_init       (EphyBookmarkAction *action);
@@ -46,6 +48,7 @@ struct EphyBookmarkActionPrivate
 	char *location;
 	gboolean smart_url;
 	char *icon;
+	guint cache_connection;
 };
 
 enum
@@ -66,7 +69,7 @@ enum
 
 static GObjectClass *parent_class = NULL;
 
-static guint ephy_bookmark_action_signals[LAST_SIGNAL] = { 0 };
+static guint signals[LAST_SIGNAL] = { 0 };
 
 GType
 ephy_bookmark_action_get_type (void)
@@ -158,14 +161,29 @@ ephy_bookmark_action_sync_smart_url (GtkAction *action, GParamSpec *pspec, GtkWi
 	}
 }
 
+static void
+favicon_cache_changed_cb (EphyFaviconCache *cache,
+			  const char *icon,
+			  EphyBookmarkAction *action)
+{
+	if (action->priv->icon && strcmp (icon, action->priv->icon) == 0)
+	{
+		g_signal_handler_disconnect (cache, action->priv->cache_connection);
+		action->priv->cache_connection = 0;
+
+		g_object_notify (G_OBJECT (action), "icon");
+	}
+}
+
 static void
 ephy_bookmark_action_sync_icon (GtkAction *action, GParamSpec *pspec, GtkWidget *proxy)
 {
+	EphyBookmarkAction *bma = EPHY_BOOKMARK_ACTION (action);
 	char *icon_location;
 	EphyFaviconCache *cache;
 	GdkPixbuf *pixbuf = NULL;
 
-	icon_location = EPHY_BOOKMARK_ACTION (action)->priv->icon;
+	icon_location = bma->priv->icon;
 
 	cache = EPHY_FAVICON_CACHE (ephy_embed_shell_get_favicon_cache
 		(EPHY_EMBED_SHELL (ephy_shell)));
@@ -173,6 +191,15 @@ ephy_bookmark_action_sync_icon (GtkAction *action, GParamSpec *pspec, GtkWidget
 	if (icon_location)
 	{
 		pixbuf = ephy_favicon_cache_get (cache, icon_location);
+
+		if (pixbuf == NULL && bma->priv->cache_connection == 0)
+		{
+			bma->priv->cache_connection =
+				g_signal_connect_object
+					(cache, "changed",
+					 G_CALLBACK (favicon_cache_changed_cb),
+					 action, 0);
+		}
 	}
 
 	if (pixbuf == NULL) return;
@@ -292,14 +319,40 @@ activate_cb (GtkWidget *widget, GtkAction *action)
 		}
 	}
 
-	g_signal_emit (action,
-		       ephy_bookmark_action_signals[GO_LOCATION],
-		       0, location);
+	g_signal_emit (action, signals[GO_LOCATION], 0, location);
 
 	g_free (location);
 	g_free (text);
 }
 
+static gboolean
+button_press_cb (GtkWidget *widget,
+		 GdkEventButton *event,
+		 gpointer dummy)
+{
+	if (event->type == GDK_BUTTON_PRESS && event->button == 2)	
+	{
+		gtk_button_pressed (GTK_BUTTON (widget));
+	}
+
+	return FALSE;
+}
+
+static gboolean
+button_release_cb (GtkWidget *widget,
+                   GdkEventButton *event,
+		   gpointer dummy)
+{
+	if (event->type == GDK_BUTTON_RELEASE && event->button == 2)	
+	{
+		gtk_button_released (GTK_BUTTON (widget));
+
+		return TRUE;
+	}
+
+	return FALSE;
+}
+
 static void
 connect_proxy (GtkAction *action, GtkWidget *proxy)
 {
@@ -325,6 +378,10 @@ connect_proxy (GtkAction *action, GtkWidget *proxy)
 	{
 		button = GTK_WIDGET (g_object_get_data (G_OBJECT (proxy), "button"));
 		g_signal_connect (button, "clicked", G_CALLBACK (activate_cb), action);
+		g_signal_connect (button, "button-press-event",
+				  G_CALLBACK (button_press_cb), NULL);
+		g_signal_connect (button, "button-release-event",
+				  G_CALLBACK (button_release_cb), NULL);
 
 		entry = GTK_WIDGET (g_object_get_data (G_OBJECT (proxy), "entry"));
 		g_signal_connect (entry, "activate", G_CALLBACK (activate_cb), action);
@@ -357,12 +414,10 @@ ephy_bookmark_action_set_property (GObject *object,
 			break;
 		case PROP_SMART_URL:
 			bmk->priv->smart_url = g_value_get_boolean (value);
-			g_object_notify (object, "smarturl");
 			break;
 		case PROP_ICON:
 			g_free (bmk->priv->icon);
 			bmk->priv->icon = g_value_dup_string (value);
-			g_object_notify (object, "icon");
 			break;
 	}
 }
@@ -425,7 +480,7 @@ ephy_bookmark_action_class_init (EphyBookmarkActionClass *class)
 	object_class->set_property = ephy_bookmark_action_set_property;
 	object_class->get_property = ephy_bookmark_action_get_property;
 
-	ephy_bookmark_action_signals[GO_LOCATION] =
+	signals[GO_LOCATION] =
                 g_signal_new ("go_location",
                               G_OBJECT_CLASS_TYPE (object_class),
                               G_SIGNAL_RUN_FIRST,
@@ -524,6 +579,29 @@ bookmarks_child_changed_cb (EphyNode *node,
 	}
 }
 
+static void
+smart_child_added_cb (EphyNode *smart_bmks,
+		      EphyNode *child,
+		      EphyBookmarkAction *action)
+{
+	if (action->priv->bookmark_id == ephy_node_get_id (child))
+	{
+		g_object_set (action, "smarturl", TRUE, NULL);
+	}
+}
+
+static void
+smart_child_removed_cb (EphyNode *smart_bmks,
+			EphyNode *child,
+			guint old_index,
+			EphyBookmarkAction *action)
+{
+	if (action->priv->bookmark_id == ephy_node_get_id (child))
+	{
+		g_object_set (action, "smarturl", FALSE, NULL);
+	}
+}
+
 static void
 ephy_bookmark_action_init (EphyBookmarkAction *action)
 {
@@ -534,12 +612,20 @@ ephy_bookmark_action_init (EphyBookmarkAction *action)
 
 	action->priv->location = NULL;
 	action->priv->icon = NULL;
+	action->priv->cache_connection = 0;
 
 	bookmarks = ephy_shell_get_bookmarks (ephy_shell);
 	node = ephy_bookmarks_get_bookmarks (bookmarks);
 	ephy_node_signal_connect_object (node, EPHY_NODE_CHILD_CHANGED,
 				         (EphyNodeCallback) bookmarks_child_changed_cb,
 				         G_OBJECT (action));
+	node = ephy_bookmarks_get_smart_bookmarks (bookmarks);
+	ephy_node_signal_connect_object (node, EPHY_NODE_CHILD_ADDED,
+					 (EphyNodeCallback) smart_child_added_cb,
+					 G_OBJECT (action));
+	ephy_node_signal_connect_object (node, EPHY_NODE_CHILD_REMOVED,
+					 (EphyNodeCallback) smart_child_removed_cb,
+					 G_OBJECT (action));
 }
 
 GtkAction *
