@@ -15,10 +15,11 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
+ *  $Id: ephy-bookmark-properties.c,v 1.30 2004/03/19 20:20:05 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include "ephy-toolbars-model.h"
@@ -242,13 +243,9 @@ title_entry_changed_cb (GtkWidget *entry, EphyBookmarkProperties *props)
 static void
 location_entry_changed_cb (GtkWidget *entry, EphyBookmarkProperties *props)
 {
-	char *text;
-
-	text = gtk_editable_get_chars (GTK_EDITABLE (entry), 0, -1);
 	ephy_bookmarks_set_address (props->priv->bookmarks,
 				    props->priv->bookmark,
-			            text);
-	g_free (text);
+			            gtk_entry_get_text (GTK_ENTRY (entry)));
 }
 
 static void
@@ -300,8 +297,11 @@ set_window_icon (EphyBookmarkProperties *editor)
 					       NULL);
 	}
 
-	gtk_window_set_icon (GTK_WINDOW (editor), icon);
-	g_object_unref (icon);
+	if (icon != NULL)
+	{
+		gtk_window_set_icon (GTK_WINDOW (editor), icon);
+		g_object_unref (icon);
+	}
 }
 
 static void
