@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- * $Id: ephy-bookmarks-editor.c,v 1.129.4.3 2004/08/23 12:45:47 chpe Exp $
+ * $Id: ephy-bookmarks-editor.c,v 1.135 2004/05/19 10:33:19 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -554,12 +554,33 @@ import_dialog_response_cb (GtkDialog *dialog, gint response,
 		if (filename == NULL)
 		{
 			EphyFileChooser *dialog;
+			GtkFileFilter *filter;
 
 			dialog = ephy_file_chooser_new (_("Import bookmarks from file"),
 							GTK_WIDGET (editor),
 							GTK_FILE_CHOOSER_ACTION_OPEN,
-							NULL);
-			/* FIXME: set up some filters perhaps ? */
+							NULL, EPHY_FILE_FILTER_NONE);
+
+			ephy_file_chooser_add_mime_filter
+				(dialog,
+				 _("Firefox/Firebird/Mozilla bookmarks"),
+				 "application/x-mozilla-bookmarks", NULL);
+
+			ephy_file_chooser_add_mime_filter
+				(dialog, _("Galeon/Konqueror bookmarks"),
+				 "application/x-xbel", NULL);
+
+			ephy_file_chooser_add_mime_filter
+				(dialog, _("Epiphany bookmarks"),
+				 "text/rdf", NULL);
+
+			filter = ephy_file_chooser_add_pattern_filter (dialog,
+							      _("All files"),
+							      "*", NULL);
+
+			gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (dialog),
+						     filter);
+
 			g_signal_connect (dialog, "response",
 					  G_CALLBACK (import_from_file_response_cb), editor);
 
@@ -587,6 +608,7 @@ cmd_bookmarks_import (GtkAction *action,
 	GtkCellRenderer *cell;
 	GtkListStore *store;
 	GtkTreeIter iter;
+	GtkTreeModel *sortmodel;
 
 	dialog = gtk_dialog_new_with_buttons (_("Import Bookmarks"),
 					     GTK_WINDOW (editor),
@@ -594,7 +616,7 @@ cmd_bookmarks_import (GtkAction *action,
 					     GTK_DIALOG_NO_SEPARATOR,
 					     GTK_STOCK_CANCEL,
 					     GTK_RESPONSE_CANCEL,
-					     GTK_STOCK_OK,
+					     _("I_mport"),
 					     GTK_RESPONSE_OK,
 					     NULL);
 	gtk_dialog_set_default_response (GTK_DIALOG (dialog), GTK_RESPONSE_OK);
@@ -608,15 +630,20 @@ cmd_bookmarks_import (GtkAction *action,
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog)->vbox), vbox,
 			    TRUE, TRUE, 0);
 
-	label = gtk_label_new (_("Choose the bookmarks source:"));
+	label = gtk_label_new (_("Import bookmarks from:"));
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 	gtk_box_pack_start (GTK_BOX (vbox), label, TRUE, TRUE, 0);
 	gtk_widget_show (label);
 
         store = GTK_LIST_STORE (gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_STRING));
-	combo = gtk_combo_box_new_with_model (GTK_TREE_MODEL (store));
-	gtk_widget_show (combo); 
+
+	sortmodel = gtk_tree_model_sort_new_with_model (GTK_TREE_MODEL (store));
+	gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (sortmodel), 0, GTK_SORT_ASCENDING);
+
+	combo = gtk_combo_box_new ();
+	gtk_combo_box_set_model(GTK_COMBO_BOX (combo), sortmodel);
+	gtk_widget_show (combo);
 	g_object_set_data (G_OBJECT (dialog), "combo_box", combo);
 	g_object_unref (store);
 
@@ -626,17 +653,19 @@ cmd_bookmarks_import (GtkAction *action,
                                         "text", 0,
                                         NULL);
 
-	add_bookmarks_source (store, _("Mozilla bookmarks"),
-			      MOZILLA_BOOKMARKS_DIR, "bookmarks.html", 4);
-	add_bookmarks_source (store, _("Firebird bookmarks"),
+	add_bookmarks_source (store, _("Firebird"),
 			      FIREBIRD_BOOKMARKS_DIR, "bookmarks.html", 4);
-	add_bookmarks_source (store, _("Galeon bookmarks"),
+	add_bookmarks_source (store, _("Firefox"),
+                              FIREFOX_BOOKMARKS_DIR, "bookmarks.html", 4);
+	add_bookmarks_source (store, _("Galeon"),
 			      GALEON_BOOKMARKS_DIR, "bookmarks.xbel", 0);
-	add_bookmarks_source (store, _("Konqueror bookmarks"),
+	add_bookmarks_source (store, _("Konqueror"),
 			      KDE_BOOKMARKS_DIR, "bookmarks.xml", 0);
+	add_bookmarks_source (store, _("Mozilla"),
+			      MOZILLA_BOOKMARKS_DIR, "bookmarks.html", 4);
 
 	gtk_list_store_append (store, &iter);
-	gtk_list_store_set (store, &iter, 0, _("Import from a file"), 1, NULL, -1);
+	gtk_list_store_set (store, &iter, 0, _("File"), 1, NULL, -1);
 
 	gtk_box_pack_start (GTK_BOX (vbox), combo, TRUE, TRUE, 0);
 	gtk_combo_box_set_active (GTK_COMBO_BOX (combo), 0);
@@ -1075,7 +1104,7 @@ remove_focus_monitor (EphyBookmarksEditor *editor, GtkWidget *widget)
                                              editor);
 }
 
-static gboolean
+static void
 ephy_bookmarks_editor_show_popup_cb (GtkWidget *view,
 				     EphyBookmarksEditor *editor)
 {
@@ -1085,8 +1114,6 @@ ephy_bookmarks_editor_show_popup_cb (GtkWidget *view,
 					    "/EphyBookmarkEditorPopup");
 	gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 2,
 			gtk_get_current_event_time ());
-
-	return TRUE;
 }
 
 static void
@@ -1169,7 +1196,7 @@ keyword_node_selected_cb (EphyNodeView *view,
 	}
 }
 
-static gboolean
+static void
 keyword_node_show_popup_cb (GtkWidget *view, EphyBookmarksEditor *editor)
 {
 	GtkWidget *widget;
@@ -1178,8 +1205,6 @@ keyword_node_show_popup_cb (GtkWidget *view, EphyBookmarksEditor *editor)
 					   "/EphyBookmarkKeywordPopup");
 	gtk_menu_popup (GTK_MENU (widget), NULL, NULL, NULL, NULL, 2,
 			gtk_get_current_event_time ());
-
-	return TRUE;
 }
 
 static void
@@ -1473,7 +1498,7 @@ ephy_bookmarks_editor_construct (EphyBookmarksEditor *editor)
 			  G_CALLBACK (node_dropped_cb),
 			  editor);
 	g_signal_connect (G_OBJECT (key_view),
-			  "popup_menu",
+			  "show_popup",
 			  G_CALLBACK (keyword_node_show_popup_cb),
 			  editor);
 
@@ -1533,7 +1558,7 @@ ephy_bookmarks_editor_construct (EphyBookmarksEditor *editor)
 			  G_CALLBACK (ephy_bookmarks_editor_node_activated_cb),
 			  editor);
 	g_signal_connect (G_OBJECT (bm_view),
-			  "popup_menu",
+			  "show_popup",
 			  G_CALLBACK (ephy_bookmarks_editor_show_popup_cb),
 			  editor);
 	selection = gtk_tree_view_get_selection (GTK_TREE_VIEW (bm_view));
