@@ -15,10 +15,12 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-completion-model.c,v 1.12 2004/02/20 22:37:42 marco Exp $
+ *  $Id: ephy-completion-model.c,v 1.13 2004/03/17 09:08:06 marco Exp $
  */
 
-#include <config.h>
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
 
 #include "ephy-completion-model.h"
 #include "ephy-node.h"
