@@ -16,9 +16,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-extension.c,v 1.3 2004/02/17 12:03:25 chpe Exp $
+ *  $Id: ephy-extension.c,v 1.4 2004/03/17 09:08:06 marco Exp $
  */
 
+#ifdef HAVE_CONFIG_H
+#include "config.h"
+#endif
+
 #include "ephy-extension.h"
 
 GType
