@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-session.c,v 1.14.4.1 2004/08/06 13:38:03 chpe Exp $
+ *  $Id: ephy-session.c,v 1.15 2004/04/05 18:06:14 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -65,6 +65,12 @@ static void ephy_session_class_init	(EphySessionClass *klass);
 static void ephy_session_iface_init	(EphyExtensionIface *iface);
 static void ephy_session_init		(EphySession *session);
 
+enum
+{
+	PROP_0,
+	PROP_ACTIVE_WINDOW
+};
+
 static GObjectClass *parent_class = NULL;
 
 GType
@@ -177,6 +183,25 @@ tabs_reordered_cb (GtkWidget *notebook,
 	ephy_session_save (session, SESSION_CRASHED);
 }
 
+static gboolean
+window_focus_in_event_cb (EphyWindow *window,
+			  GdkEventFocus *event,
+			  EphySession *session)
+{
+	LOG ("focus-in-event for window %p", window)
+
+	g_return_val_if_fail (g_list_find (session->priv->windows, window) != NULL, FALSE);
+
+	/* move the active window to the front of the list */
+	session->priv->windows = g_list_remove (session->priv->windows, window);
+	session->priv->windows = g_list_prepend (session->priv->windows, window);
+
+	g_object_notify (G_OBJECT (session), "active-window");
+
+	/* propagate event */
+	return FALSE;
+}
+
 static void
 impl_attach_window (EphyExtension *extension,
 		    EphyWindow *window)
@@ -189,6 +214,9 @@ impl_attach_window (EphyExtension *extension,
 	session->priv->windows = g_list_append (session->priv->windows, window);
 	ephy_session_save (session, SESSION_CRASHED);
 
+	g_signal_connect (window, "focus-in-event",
+			  G_CALLBACK (window_focus_in_event_cb), session);
+
 	notebook = ephy_window_get_notebook (window);
 	g_signal_connect (notebook, "tab_added",
 			  G_CALLBACK (tab_added_cb), session);
@@ -273,6 +301,33 @@ ephy_session_iface_init (EphyExtensionIface *iface)
 	iface->detach_window = impl_detach_window;
 }
 
+static void
+ephy_session_set_property (GObject *object,
+			   guint prop_id,
+			   const GValue *value,
+			   GParamSpec *pspec)
+{
+	/* no writeable properties */
+}
+
+static void
+ephy_session_get_property (GObject *object,
+			   guint prop_id,
+			   GValue *value,
+			   GParamSpec *pspec)
+{
+	EphySession *session = EPHY_SESSION (object);
+
+	switch (prop_id)
+	{
+		case PROP_ACTIVE_WINDOW:
+			g_value_set_object (value, ephy_session_get_active_window (session));
+			break;
+		default:
+			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
+	}
+}
+
 static void
 ephy_session_class_init (EphySessionClass *class)
 {
@@ -282,6 +337,17 @@ ephy_session_class_init (EphySessionClass *class)
 
 	object_class->dispose = ephy_session_dispose;
 	object_class->finalize = ephy_session_finalize;
+	object_class->get_property = ephy_session_get_property;
+	object_class->set_property = ephy_session_set_property;
+
+	g_object_class_install_property
+		(object_class,
+		 PROP_ACTIVE_WINDOW,
+		 g_param_spec_object ("active-window",
+		 		      "Active Window",
+		 		      "The active window",
+				       EPHY_TYPE_WINDOW,
+				       G_PARAM_READABLE));
 
 	g_type_class_add_private (object_class, sizeof (EphySessionPrivate));
 }
@@ -679,7 +745,7 @@ ephy_session_load (EphySession *session,
 			}
 			else if (id && xmlStrEqual (HISTORY_WINDOW_ID, id))
 			{
-				if (!eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_HISTORY))
+				if (eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_HISTORY))
 				{
 					widget = ephy_shell_get_history_window (ephy_shell);
 				}
