@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-statusbar.c,v 1.3 2004/03/01 18:19:10 chpe Exp $
+ *  $Id: ephy-statusbar.c,v 1.6 2004/05/20 22:43:09 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -33,7 +33,7 @@
 #include <gtk/gtkeventbox.h>
 #include <gtk/gtkimage.h>
 #include <gtk/gtkframe.h>
-#include <gtk/gtktooltips.h>
+#include <gtk/gtkwidget.h>
 
 static void ephy_statusbar_class_init	(EphyStatusbarClass *klass);
 static void ephy_statusbar_init		(EphyStatusbar *t);
@@ -45,9 +45,10 @@ static GObjectClass *parent_class = NULL;
 
 struct EphyStatusbarPrivate
 {
+	GtkWidget *icon_container;
+
 	GtkWidget *security_icon;
 	GtkWidget *progressbar;
-	GtkTooltips *tooltips;
 	GtkWidget *security_evbox;
 };
 
@@ -111,9 +112,9 @@ create_statusbar_security_icon (EphyStatusbar *s)
 
 	gtk_widget_show_all (s->security_frame);
 
-	gtk_box_pack_end (GTK_BOX (s),
-			  GTK_WIDGET (s->security_frame),
-			  FALSE, TRUE, 0);
+	gtk_box_pack_start (GTK_BOX (s->priv->icon_container),
+			    GTK_WIDGET (s->security_frame),
+			    FALSE, TRUE, 0);
 }
 
 static void
@@ -122,9 +123,32 @@ create_statusbar_progress (EphyStatusbar *s)
 	s->priv->progressbar = gtk_progress_bar_new ();
 	gtk_widget_show_all (s->priv->progressbar);
 
-	gtk_box_pack_start (GTK_BOX (s),
-			    GTK_WIDGET (s->priv->progressbar),
-			    FALSE, TRUE, 0);
+	gtk_box_pack_end (GTK_BOX (s),
+			  GTK_WIDGET (s->priv->progressbar),
+			  FALSE, TRUE, 0);
+}
+
+static void
+sync_shadow_type (EphyStatusbar *statusbar,
+		  GParamSpec *pspec,
+		  gpointer dummy)
+{
+	GtkShadowType shadow;
+	GList *children, *l;
+
+	gtk_widget_style_get (GTK_WIDGET (statusbar), "shadow-type",
+			      &shadow, NULL);
+
+	children = gtk_container_get_children
+		(GTK_CONTAINER (statusbar->priv->icon_container));
+	for (l = children; l != NULL; l = l->next)
+	{
+		if (GTK_IS_FRAME (l->data))
+		{
+			gtk_frame_set_shadow_type (GTK_FRAME (l->data), shadow);
+		}
+	}
+	g_list_free (children);
 }
 
 static void
@@ -132,14 +156,25 @@ ephy_statusbar_init (EphyStatusbar *t)
 {
 	t->priv = EPHY_STATUSBAR_GET_PRIVATE (t);
 
-	t->priv->tooltips = gtk_tooltips_new ();
-	g_object_ref (G_OBJECT (t->priv->tooltips));
-	gtk_object_sink (GTK_OBJECT (t->priv->tooltips));
+	t->tooltips = gtk_tooltips_new ();
+	g_object_ref (G_OBJECT (t->tooltips));
+	gtk_object_sink (GTK_OBJECT (t->tooltips));
 
+	t->priv->icon_container = gtk_hbox_new (FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (t), t->priv->icon_container, FALSE, FALSE, 0);
+	gtk_box_reorder_child (GTK_BOX (t), t->priv->icon_container, 0);
+	gtk_widget_show (t->priv->icon_container);
+
+	/* FIXME: enable this when gtk+ bug 73359 is fixed */
 	gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (t), FALSE);
 
 	create_statusbar_progress (t);
 	create_statusbar_security_icon (t);
+
+	/* FIXME: is this the right way ? */
+	sync_shadow_type (t, NULL, NULL);
+	g_signal_connect (t, "notify::shadow-type",
+			  G_CALLBACK (sync_shadow_type), NULL);
 }
 
 static void
@@ -147,7 +182,7 @@ ephy_statusbar_finalize (GObject *object)
 {
 	EphyStatusbar *t = EPHY_STATUSBAR (object);
 
-	g_object_unref (t->priv->tooltips);
+	g_object_unref (t->tooltips);
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -185,15 +220,14 @@ ephy_statusbar_set_security_state (EphyStatusbar *statusbar,
 	gtk_image_set_from_stock (GTK_IMAGE (statusbar->priv->security_icon), stock,
 				  GTK_ICON_SIZE_MENU);
 
-	gtk_tooltips_set_tip (statusbar->priv->tooltips, statusbar->priv->security_evbox,
+	gtk_tooltips_set_tip (statusbar->tooltips, statusbar->priv->security_evbox,
 			      tooltip, NULL);
 }
 
 /**
  * ephy_statusbar_set_progress:
  * @statusbar: a #EphyStatusbar
- * @progress: the progress as an integer between 0 and 100, or -1 to show
- * interminate progress
+ * @progress: the progress as an integer between 0 and 100 per cent.
  * 
  * Sets the statusbar's progress.
  **/
@@ -201,16 +235,16 @@ void
 ephy_statusbar_set_progress (EphyStatusbar *statusbar,
 			     int progress)
 {
-	if (progress == -1)
+	gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (statusbar->priv->progressbar),
+				       (float) (progress) / 100.0);
+
+	if (progress < 100)
 	{
-		gtk_progress_bar_pulse (GTK_PROGRESS_BAR (statusbar->priv->progressbar));
+		gtk_widget_show (statusbar->priv->progressbar);
 	}
 	else
 	{
-		float fraction;
-		fraction = (float)(progress) / 100;
-		gtk_progress_bar_set_fraction (GTK_PROGRESS_BAR (statusbar->priv->progressbar),
-					       fraction);
+		gtk_widget_hide (statusbar->priv->progressbar);
 	}
 }
 
@@ -230,5 +264,15 @@ ephy_statusbar_add_widget (EphyStatusbar *statusbar,
 	g_return_if_fail (EPHY_IS_STATUSBAR (statusbar));
 	g_return_if_fail (GTK_IS_WIDGET (widget));
 
-	gtk_box_pack_start (GTK_BOX (statusbar), widget, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (statusbar->priv->icon_container),
+			    widget, FALSE, FALSE, 0);
+
+	if (GTK_IS_FRAME (widget))
+	{
+		GtkShadowType shadow;
+
+		gtk_widget_style_get (GTK_WIDGET (statusbar), "shadow-type",
+				      &shadow, NULL);
+		gtk_frame_set_shadow_type (GTK_FRAME (widget), shadow);
+	}
 }
