@@ -14,6 +14,8 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ *  $Id: ephy-toolbars-model.h,v 1.13 2004/03/17 09:08:06 marco Exp $
  */
 
 #ifndef EPHY_TOOLBARS_MODEL_H
@@ -68,12 +70,6 @@ char              *ephy_toolbars_model_get_action_name (EphyToolbarsModel *model
 EphyNode	  *ephy_toolbars_model_get_node        (EphyToolbarsModel *model,
 			                                const char *action_name);
 
-void		   ephy_toolbars_model_set_flag        (EphyToolbarsModel *model,
-							EggTbModelFlags flags);
-
-void		   ephy_toolbars_model_unset_flag      (EphyToolbarsModel *model,
-							EggTbModelFlags flags);
-
 G_END_DECLS
 
 #endif
