@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-window.c,v 1.169.4.14 2004/11/03 21:41:36 chpe Exp $
+ *  $Id: ephy-window.c,v 1.185 2004/05/19 18:45:34 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -103,6 +103,9 @@ static GtkActionEntry ephy_menu_entries [] = {
 	{ "FileSaveAs", GTK_STOCK_SAVE_AS, N_("Save _As..."), "<shift><control>S",
 	  N_("Save the current page"),
 	  G_CALLBACK (window_cmd_file_save_as) },
+	{ "FileSave", GTK_STOCK_SAVE_AS, N_("Save _As..."), "<control>S",
+	  N_("Save the current page"),
+	  G_CALLBACK (window_cmd_file_save_as) },
 	{ "FilePrintSetup", STOCK_PRINT_SETUP, N_("Print Set_up..."), NULL,
 	  N_("Setup the page settings for printing"),
 	  G_CALLBACK (window_cmd_file_print_setup) },
@@ -267,10 +270,6 @@ static GtkActionEntry ephy_popups_entries [] = {
 	/* Framed document */
 	{ "OpenFrame", NULL, N_("_Open Frame"), NULL,
 	  NULL, G_CALLBACK (popup_cmd_open_frame) },
-	{ "OpenFrameInNewWindow", NULL, N_("Open Frame in _New Window"), NULL,
-	  NULL, G_CALLBACK (popup_cmd_frame_in_new_window) },
-	{ "OpenFrameInNewTab", NULL, N_("Open Frame in New _Tab"), NULL,
-	  NULL, G_CALLBACK (popup_cmd_frame_in_new_tab) },
 
 	/* Links */
 	{ "OpenLink", GTK_STOCK_OPEN, N_("_Open Link"),
@@ -291,10 +290,6 @@ static GtkActionEntry ephy_popups_entries [] = {
 	/* Images */
 	{ "OpenImage", GTK_STOCK_OPEN, N_("Open _Image"), NULL,
 	  NULL, G_CALLBACK (popup_cmd_open_image) },
-	{ "OpenImageInNewWindow", NULL, N_("Open Image in New _Window"), NULL,
-	  NULL, G_CALLBACK (popup_cmd_image_in_new_window) },
-	{ "OpenImageInNewTab", NULL, N_("Open Image in New T_ab"), NULL,
-	  NULL, G_CALLBACK (popup_cmd_image_in_new_tab) },
 	{ "SaveImageAs", GTK_STOCK_SAVE_AS, N_("_Save Image As..."), NULL,
 	  NULL, G_CALLBACK (popup_cmd_save_image_as) },
 	{ "SetImageAsBackground", NULL, N_("_Use Image As Background"), NULL,
@@ -334,6 +329,7 @@ struct EphyWindowPrivate
 	GtkNotebook *notebook;
 	EphyTab *active_tab;
 	EphyDialog *find_dialog;
+	EphyDialog *print_dialog;
 	gboolean closing;
 	gboolean has_size;
 	guint num_tabs;
@@ -390,33 +386,6 @@ ephy_window_get_type (void)
         return ephy_window_type;
 }
 
-static void
-update_exit_fullscreen_popup_position (EphyWindow *window)
-{
-	GdkRectangle screen_rect;
-        int popup_height;
-
-        g_return_if_fail (window->priv->exit_fullscreen_popup != NULL);
-
-        gtk_window_get_size (GTK_WINDOW (window->priv->exit_fullscreen_popup),
-                             NULL, &popup_height);
-
-        gdk_screen_get_monitor_geometry (gdk_screen_get_default (),
-                        gdk_screen_get_monitor_at_window
-                        (gdk_screen_get_default (),
-                         GTK_WIDGET (window)->window),
-                         &screen_rect);
-
-        gtk_window_move (GTK_WINDOW (window->priv->exit_fullscreen_popup),
-                        screen_rect.x, screen_rect.height - popup_height);
-}
-
-static void
-size_changed_cb (GdkScreen *screen, EphyWindow *window)
-{
-	update_exit_fullscreen_popup_position (window);
-}
-
 static void
 ephy_window_destroy (GtkObject *gtkobject)
 {
@@ -437,10 +406,6 @@ ephy_window_destroy (GtkObject *gtkobject)
 
 	if (window->priv->exit_fullscreen_popup)
 	{
-		g_signal_handlers_disconnect_by_func
-			(gdk_screen_get_default (),
-			 G_CALLBACK (size_changed_cb), window);
-
 		gtk_widget_destroy (window->priv->exit_fullscreen_popup);
 		window->priv->exit_fullscreen_popup = NULL;
 	}
@@ -455,6 +420,33 @@ add_widget (GtkUIManager *merge, GtkWidget *widget, EphyWindow *window)
 			    widget, FALSE, FALSE, 0);
 }
 
+static void
+update_exit_fullscreen_popup_position (EphyWindow *window)
+{
+	GdkRectangle screen_rect;
+	int popup_height;
+
+	g_return_if_fail (window->priv->exit_fullscreen_popup != NULL);
+
+	gtk_window_get_size (GTK_WINDOW (window->priv->exit_fullscreen_popup),
+                             NULL, &popup_height);
+
+	gdk_screen_get_monitor_geometry (gdk_screen_get_default (),
+                        gdk_screen_get_monitor_at_window
+                        (gdk_screen_get_default (),
+                         GTK_WIDGET (window)->window),
+                         &screen_rect);
+
+	gtk_window_move (GTK_WINDOW (window->priv->exit_fullscreen_popup),
+                        screen_rect.x, screen_rect.height - popup_height);
+}
+
+static void
+size_changed_cb (GdkScreen *screen, EphyWindow *window)
+{
+	update_exit_fullscreen_popup_position (window);
+}
+
 static void
 exit_fullscreen_button_clicked_cb (GtkWidget *button, EphyWindow *window)
 {
@@ -621,7 +613,7 @@ confirm_close_with_modified_forms (EphyWindow *window)
 					      GTK_WINDOW (window),
 					      GTK_DIALOG_NO_SEPARATOR | GTK_DIALOG_MODAL,
 					      GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL,
-					      _("_Close document"), GTK_RESPONSE_OK,
+					      _("Close _Document"), GTK_RESPONSE_OK,
 					      NULL);
 	
 	gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
@@ -644,6 +636,7 @@ confirm_close_with_modified_forms (EphyWindow *window)
 	gtk_box_pack_start (GTK_BOX (hbox), vbox, TRUE, TRUE, 0);
 
 	label = gtk_label_new (NULL);
+	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (label), 0.0, 0.5);
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
 
@@ -678,7 +671,7 @@ ephy_window_delete_event_cb (GtkWidget *widget, GdkEvent *event, EphyWindow *win
 		EphyEmbed *embed;
 
 		embed = ephy_window_get_active_embed (window);
-		ephy_embed_set_print_preview_mode (embed, FALSE);
+		ephy_embed_print_preview_close (embed);
 
 		ephy_window_set_print_preview (window, FALSE);
 	}
@@ -1374,9 +1367,6 @@ hide_embed_popup_cb (GtkWidget *popup,
 			EphyWindow *window)
 {
 	enable_edit_actions_sensitivity (window);
-
-	g_signal_handlers_disconnect_by_func
-		(popup, G_CALLBACK (hide_embed_popup_cb), window);
 }
 
 static void
@@ -1390,6 +1380,7 @@ show_embed_popup (EphyWindow *window, EphyTab *tab, EphyEmbedEvent *event)
 	gboolean framed, has_background, can_open_in_new;
 	GtkWidget *widget;
 	EphyEmbedEventType type;
+	gboolean showing_edit_actions = FALSE;
 
 	/* Do not show the menu in print preview mode */
 	if (window->priv->mode == EPHY_WINDOW_MODE_PRINT_PREVIEW)
@@ -1405,6 +1396,8 @@ show_embed_popup (EphyWindow *window, EphyTab *tab, EphyEmbedEvent *event)
 
 	context = ephy_embed_event_get_context (event);
 
+	LOG ("show_embed_popup context %x", context)
+
 	if ((context & EMBED_CONTEXT_LINK) &&
 	    (context & EMBED_CONTEXT_IMAGE))
 	{
@@ -1412,25 +1405,23 @@ show_embed_popup (EphyWindow *window, EphyTab *tab, EphyEmbedEvent *event)
 	}
 	else if (context & EMBED_CONTEXT_LINK)
 	{
+		showing_edit_actions = TRUE;
 		popup = "/EphyLinkPopup";
-		update_edit_actions_sensitivity (window, TRUE);
 	}
 	else if (context & EMBED_CONTEXT_IMAGE)
 	{
 		popup = "/EphyImagePopup";
 	}
-#if MOZILLA_SNAPSHOT > 12
 	else if (context & EMBED_CONTEXT_INPUT)
 	{
+		showing_edit_actions = TRUE;
 		popup = "/EphyInputPopup";
-		update_edit_actions_sensitivity (window, FALSE);
 	}
-#endif
 	else
 	{
+		showing_edit_actions = TRUE;
 		popup = framed ? "/EphyFramedDocumentPopup" :
 				 "/EphyDocumentPopup";
-		update_edit_actions_sensitivity (window, TRUE);
 	}
 
 	widget = gtk_ui_manager_get_widget (GTK_UI_MANAGER (window->ui_merge),
@@ -1446,6 +1437,11 @@ show_embed_popup (EphyWindow *window, EphyTab *tab, EphyEmbedEvent *event)
 	action = gtk_action_group_get_action (action_group, "OpenLinkInNewTab");
 	g_object_set (action, "sensitive", can_open_in_new, FALSE);
 
+	if (showing_edit_actions)
+	{
+		update_edit_actions_sensitivity (window, TRUE);
+	}
+
 	g_object_set_data_full (G_OBJECT (window), "context_event",
 				g_object_ref (event),
 				(GDestroyNotify)g_object_unref);
@@ -1483,9 +1479,6 @@ tab_context_menu_cb (EphyEmbed *embed,
 	g_return_val_if_fail (EPHY_IS_TAB (tab), FALSE);
 	g_return_val_if_fail (window->priv->active_tab == tab, FALSE);
 
-	window = ephy_tab_get_window (tab);
-	g_return_val_if_fail (window != NULL, FALSE);
-
 	show_embed_popup (window, tab, event);
 
 	return FALSE;
@@ -1499,7 +1492,7 @@ ephy_window_set_active_tab (EphyWindow *window, EphyTab *new_tab)
 	GtkToggleAction *action;
 
 	g_return_if_fail (EPHY_IS_WINDOW (window));
-	if (ephy_tab_get_window (new_tab) != window) return;
+	g_return_if_fail (gtk_widget_get_toplevel (GTK_WIDGET (new_tab)) == GTK_WIDGET (window));
 
 	old_tab = window->priv->active_tab;
 
@@ -1638,39 +1631,11 @@ update_tabs_menu_sensitivity (EphyWindow *window)
 	g_object_set (action, "sensitive", detach, NULL);
 }
 
-static gboolean
-modal_alert_cb (EphyEmbed *embed,
-		EphyWindow *window)
-{
-	EphyTab *tab;
-	char *address;
-
-	tab = ephy_tab_for_embed (embed);
-	g_return_val_if_fail (tab != NULL, FALSE);
-
-	/* switch the window to the tab, and bring the window to the foreground
-	 * (since the alert is modal, the user won't be able to do anything
-	 * with his current window anyway :|)
-	 */
-	ephy_window_jump_to_tab (window, tab);
-	gtk_window_present (GTK_WINDOW (window));
-
-	/* make sure the location entry shows the real URL of the tab's page */
-	address = ephy_embed_get_location (embed, TRUE);
-	toolbar_set_location (window->priv->toolbar, address);
-	g_free (address);
-
-	/* don't suppress alert */
-	return FALSE;
-}
-
 static void
 tab_added_cb (EphyNotebook *notebook,
 	      EphyTab *tab,
 	      EphyWindow *window)
 {
-	EphyEmbed *embed;
-
         g_return_if_fail (EPHY_IS_TAB (tab));
 
 	window->priv->num_tabs++;
@@ -1679,12 +1644,6 @@ tab_added_cb (EphyNotebook *notebook,
 
 	g_signal_connect_object (G_OBJECT (tab), "notify::visible",
 				 G_CALLBACK (sync_tab_visibility), window, 0);
-
-	embed = ephy_tab_get_embed (tab);
-	g_return_if_fail (embed != NULL);
-
-	g_signal_connect_after (embed, "ge-modal-alert",
-				G_CALLBACK (modal_alert_cb), window);
 }
 
 static void
@@ -1692,8 +1651,6 @@ tab_removed_cb (EphyNotebook *notebook,
 		EphyTab *tab,
 		EphyWindow *window)
 {
-	EphyEmbed *embed;
-
         g_return_if_fail (EPHY_IS_TAB (tab));
 
 	g_signal_handlers_disconnect_by_func (G_OBJECT (tab),
@@ -1706,12 +1663,6 @@ tab_removed_cb (EphyNotebook *notebook,
 	{
 		update_tabs_menu_sensitivity (window);
 	}
-
-	embed = ephy_tab_get_embed (tab);
-	g_return_if_fail (embed != NULL);
-
-	g_signal_handlers_disconnect_by_func
-		(embed, G_CALLBACK (modal_alert_cb), window);
 }
 
 static void
@@ -2095,6 +2046,11 @@ ephy_window_finalize (GObject *object)
 		g_object_unref (G_OBJECT (window->priv->find_dialog));
 	}
 
+	if (window->priv->print_dialog)
+	{
+		g_object_unref (G_OBJECT (window->priv->print_dialog));
+	}
+
 	g_object_unref (window->priv->fav_menu);
 	g_object_unref (window->priv->enc_menu);
 	g_object_unref (window->priv->tabs_menu);
@@ -2115,12 +2071,28 @@ ephy_window_finalize (GObject *object)
 	g_object_unref (ephy_shell);
 }
 
+/**
+ * ephy_window_new:
+ *
+ * Equivalent to g_object_new() but returns an #EphyWindow so you don't have
+ * to cast it.
+ *
+ * Return value: a new #EphyWindow
+ **/
 EphyWindow *
 ephy_window_new (void)
 {
 	return EPHY_WINDOW (g_object_new (EPHY_TYPE_WINDOW, NULL));
 }
 
+/**
+ * ephy_window_new_with_chrome:
+ * @chrome: an #EphyEmbedChrome
+ *
+ * Identical to ephy_window_new(), but allows you to specify a chrome.
+ *
+ * Return value: a new #EphyWindow
+ **/
 EphyWindow *
 ephy_window_new_with_chrome (EphyEmbedChrome chrome)
 {
@@ -2129,6 +2101,13 @@ ephy_window_new_with_chrome (EphyEmbedChrome chrome)
 					  NULL));
 }
 
+/**
+ * ephy_window_set_print_preview:
+ * @window: an #EphyWindow
+ * @enabled: %TRUE to enable print preview mode
+ *
+ * Sets whether the window is in print preview mode.
+ **/
 void
 ephy_window_set_print_preview (EphyWindow *window, gboolean enabled)
 {
@@ -2164,6 +2143,16 @@ ephy_window_set_print_preview (EphyWindow *window, gboolean enabled)
 	}
 }
 
+/**
+ * ephy_window_get_toolbar:
+ * @window: an #EphyWindow
+ *
+ * Returns this window's toolbar as an #EggEditableToolbar. Note that this
+ * toolbar is uneditable outside of Epiphany itself (i.e., extensions should not
+ * access it).
+ *
+ * Return value: an #EggEditableToolbar
+ **/
 GtkWidget *
 ephy_window_get_toolbar (EphyWindow *window)
 {
@@ -2172,6 +2161,14 @@ ephy_window_get_toolbar (EphyWindow *window)
 	return GTK_WIDGET (window->priv->toolbar);
 }
 
+/**
+ * ephy_window_get_notebook:
+ * @window: an #EphyWindow
+ *
+ * Returns the #GtkNotebook used by this window.
+ *
+ * Return value: the @window's #GtkNotebook
+ **/
 GtkWidget *
 ephy_window_get_notebook (EphyWindow *window)
 {
@@ -2180,6 +2177,14 @@ ephy_window_get_notebook (EphyWindow *window)
 	return GTK_WIDGET (window->priv->notebook);
 }
 
+/**
+ * ephy_window_get_statusbar:
+ * @window: an #EphyWindow
+ *
+ * Returns this window's statusbar as an #EphyStatusbar.
+ *
+ * Return value: This window's statusbar
+ **/
 GtkWidget *
 ephy_window_get_statusbar (EphyWindow *window)
 {
@@ -2188,6 +2193,15 @@ ephy_window_get_statusbar (EphyWindow *window)
 	return GTK_WIDGET (window->priv->statusbar);
 }
 
+/**
+ * ephy_window_add_tab:
+ * @window: an #EphyWindow
+ * @tab: an #EphyTab
+ * @position: the position in @window's #GtkNotebook
+ * @jump_to: %TRUE to switch to @tab's new notebook page after insertion
+ *
+ * Inserts @tab into @window.
+ **/
 void
 ephy_window_add_tab (EphyWindow *window,
 		     EphyTab *tab,
@@ -2205,6 +2219,13 @@ ephy_window_add_tab (EphyWindow *window,
 				  tab, position, jump_to);
 }
 
+/**
+ * ephy_window_jump_to_tab:
+ * @window: an #EphyWindow
+ * @tab: an #EphyTab inside @window
+ *
+ * Switches @window's #GtkNotebook to open @tab as its current page.
+ **/
 void
 ephy_window_jump_to_tab (EphyWindow *window,
 			 EphyTab *tab)
@@ -2233,6 +2254,13 @@ real_get_active_tab (EphyWindow *window, int page_num)
 	return EPHY_TAB (tab);
 }
 
+/**
+ * ephy_window_remove_tab:
+ * @window: an #EphyWindow
+ * @tab: an #EphyTab
+ *
+ * Removes @tab from @window.
+ **/
 void
 ephy_window_remove_tab (EphyWindow *window,
 		        EphyTab *tab)
@@ -2262,8 +2290,8 @@ ephy_window_remove_tab (EphyWindow *window,
  * @window: a #EphyWindow
  * @url: the url to load
  *
- * Load a new url in the active tab of the window.
- * Unlike ephy_embed_load_url this function activate
+ * Loads a new url in the active tab of @window.
+ * Unlike ephy_embed_load_url(), this function activates
  * the embed.
  *
  **/
@@ -2282,11 +2310,24 @@ ephy_window_load_url (EphyWindow *window,
 	ephy_embed_activate (embed);
 }
 
-void ephy_window_activate_location (EphyWindow *window)
+/**
+ * ephy_window_activate_location:
+ * @window: an #EphyWindow
+ *
+ * Activates the location entry on @window's toolbar.
+ **/
+void
+ephy_window_activate_location (EphyWindow *window)
 {
 	toolbar_activate_location (window->priv->toolbar);
 }
 
+/**
+ * ephy_window_show:
+ * @widget: an #EphyWindow
+ *
+ * Shows @widget if it is hidden.
+ **/
 void
 ephy_window_show (GtkWidget *widget)
 {
@@ -2313,6 +2354,14 @@ ephy_window_show (GtkWidget *widget)
 	GTK_WIDGET_CLASS (parent_class)->show (widget);
 }
 
+/**
+ * ephy_window_get_active_tab:
+ * @window: an #EphyWindow
+ *
+ * Returns @window's active #EphyTab.
+ *
+ * Return value: @window's active tab
+ **/
 EphyTab *
 ephy_window_get_active_tab (EphyWindow *window)
 {
@@ -2322,6 +2371,15 @@ ephy_window_get_active_tab (EphyWindow *window)
 	return window->priv->active_tab;
 }
 
+/**
+ * ephy_window_get_active_embed:
+ * @window: an #EphyWindow
+ *
+ * Return @window's active #EphyEmbed. This is identical to calling
+ * ephy_window_get_active_tab() followed by ephy_tab_get_embed().
+ *
+ * Return value: @window's active embed
+ **/
 EphyEmbed *
 ephy_window_get_active_embed (EphyWindow *window)
 {
@@ -2341,6 +2399,7 @@ ephy_window_get_active_embed (EphyWindow *window)
  *
  * Returns the list of #EphyTab:s in the window.
  *
+ * Return value: a newly-allocated list of #EphyTab:s
  */
 GList *
 ephy_window_get_tabs (EphyWindow *window)
@@ -2365,6 +2424,7 @@ update_embed_dialogs (EphyWindow *window,
 {
 	EphyEmbed *embed;
 	EphyDialog *find_dialog = window->priv->find_dialog;
+	EphyDialog *print_dialog = window->priv->print_dialog;
 
 	embed = ephy_tab_get_embed (tab);
 
@@ -2374,6 +2434,13 @@ update_embed_dialogs (EphyWindow *window,
 			(EPHY_EMBED_DIALOG(find_dialog),
 			 embed);
 	}
+
+	if (print_dialog)
+	{
+		ephy_embed_dialog_set_embed
+			(EPHY_EMBED_DIALOG(print_dialog),
+			 embed);
+	}
 }
 
 static void
@@ -2399,6 +2466,12 @@ ephy_window_notebook_switch_page_cb (GtkNotebook *notebook,
 	update_tabs_menu_sensitivity (window);
 }
 
+/**
+ * ephy_window_find:
+ * @window: an #EphyWindow
+ *
+ * Displays @window's Find dialog.
+ **/
 void
 ephy_window_find (EphyWindow *window)
 {
@@ -2421,6 +2494,62 @@ ephy_window_find (EphyWindow *window)
 	ephy_dialog_show (window->priv->find_dialog);
 }
 
+/**
+ * ephy_window_print:
+ * @window: an #EphyWindow
+ *
+ * Displays @window's Print dialog.
+ **/
+void
+ephy_window_print (EphyWindow *window)
+{
+	if (eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_PRINTING))
+	{
+		return;
+	}
+
+	if (eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_PRINT_SETUP) ||
+	    eel_gconf_get_boolean (CONF_LOCKDOWN_DISABLE_COMMAND_LINE))
+	{
+		EphyEmbed *embed;
+		EmbedPrintInfo *info;
+
+		info = ephy_print_get_print_info ();
+
+		embed = ephy_window_get_active_embed (window);
+		g_return_if_fail (EPHY_IS_EMBED (embed));
+
+		ephy_embed_print (embed, info);
+
+		ephy_print_info_free (info);
+
+		return;
+	}
+
+	if (window->priv->print_dialog == NULL)
+	{
+		EphyDialog *dialog;
+		EphyEmbed *embed;
+
+		embed = ephy_window_get_active_embed (window);
+		dialog = ephy_print_dialog_new  (GTK_WIDGET (window), embed, FALSE);
+
+		window->priv->print_dialog = dialog;
+		g_object_add_weak_pointer(G_OBJECT (dialog),
+					  (gpointer *) &window->priv->print_dialog);
+	}
+
+	ephy_dialog_show (window->priv->print_dialog);
+}
+
+/**
+ * ephy_window_set_zoom:
+ * @window: an #EphyWindow
+ * @zoom: the desired zoom level
+ *
+ * Sets the zoom on @window's active #EphyEmbed. A @zoom of 1.0 corresponds to
+ * 100% zoom (normal size).
+ **/
 void
 ephy_window_set_zoom (EphyWindow *window,
 		      float zoom)
@@ -2433,7 +2562,7 @@ ephy_window_set_zoom (EphyWindow *window,
 	embed = ephy_window_get_active_embed (window);
         g_return_if_fail (embed != NULL);
 
-	current_zoom = ephy_embed_zoom_get (embed);
+	current_zoom = ephy_embed_get_zoom (embed);
 
 	if (zoom == ZOOM_IN)
 	{
@@ -2446,7 +2575,7 @@ ephy_window_set_zoom (EphyWindow *window,
 
 	if (zoom != current_zoom)
 	{
-		ephy_embed_zoom_set (embed, zoom, TRUE);
+		ephy_embed_set_zoom (embed, zoom, TRUE);
 	}
 }
 
