@@ -1,6 +1,7 @@
 /*
  *  Copyright (C) 2002 Jorn Baayen
  *  Copyright (C) 2003 Marco Pesenti Gritti
+ *  Copyright (C) 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: pdm-dialog.c,v 1.33 2004/01/04 22:12:09 chpe Exp $
+ *  $Id: pdm-dialog.c,v 1.36 2004/03/18 16:52:56 piers Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -26,6 +27,7 @@
 #include "pdm-dialog.h"
 #include "ephy-shell.h"
 #include "ephy-cookie-manager.h"
+#include "ephy-file-helpers.h"
 #include "ephy-password-manager.h"
 #include "ephy-gui.h"
 #include "ephy-ellipsizing-label.h"
@@ -784,8 +786,9 @@ pdm_dialog_init (PdmDialog *dialog)
 
 	ephy_dialog_construct (EPHY_DIALOG(dialog),
 			       properties,
-			       "epiphany.glade",
-			       "pdm_dialog");
+			       ephy_file ("epiphany.glade"),
+			       "pdm_dialog",
+			       NULL);
 
 	/**
 	 * Group all Properties and Remove buttons in the same size group to
@@ -908,7 +911,7 @@ show_cookies_properties (PdmDialog *dialog,
 	gtk_widget_show (label);
 	gtk_table_attach_defaults (GTK_TABLE (table), label, 1, 2, 1, 2);
 
-	str = g_strconcat ("<b>", _("Secure:"), "</b>", NULL);
+	str = g_strconcat ("<b>", _("Send for:"), "</b>", NULL);
 	label = gtk_label_new (str);
 	g_free (str);
 	gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
@@ -917,7 +920,7 @@ show_cookies_properties (PdmDialog *dialog,
 	gtk_table_attach (GTK_TABLE (table), label, 0, 1, 2, 3,
 			  GTK_FILL, GTK_FILL, 0, 0);
 
-	label = gtk_label_new (info->is_secure ? _("Yes") : _("No") );
+	label = gtk_label_new (info->is_secure ? _("Encrypted connections only") : _("Any type of connection") );
 	gtk_label_set_selectable (GTK_LABEL (label), TRUE);
 	gtk_misc_set_alignment (GTK_MISC (label), 0, 0);
 	gtk_widget_show (label);
