@@ -15,15 +15,13 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: window-commands.c,v 1.115.4.9 2004/09/22 19:16:35 chpe Exp $
+ *  $Id: window-commands.c,v 1.123 2004/05/29 18:53:25 chpe Exp $
  */
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
-#include "ephy-embed-shell.h"
-#include "ephy-embed-single.h"
 #include "ephy-shell.h"
 #include "ephy-embed-factory.h"
 #include "ephy-embed-persist.h"
@@ -75,10 +73,12 @@ void
 window_cmd_file_print_setup (GtkAction *action,
 			     EphyWindow *window)
 {
-	EphyEmbedSingle *single;
+	EphyDialog *dialog;
 
-	single = EPHY_EMBED_SINGLE (ephy_embed_shell_get_embed_single (embed_shell));
-	ephy_embed_single_print_setup (single);
+	dialog = EPHY_DIALOG (ephy_shell_get_print_setup_dialog (ephy_shell));
+	ephy_dialog_set_parent (dialog, GTK_WIDGET (window));
+
+	ephy_dialog_show (dialog);
 }
 
 void
@@ -86,11 +86,18 @@ window_cmd_file_print_preview (GtkAction *action,
 			       EphyWindow *window)
 {
 	EphyEmbed *embed;
+	EmbedPrintInfo *info;
 
 	embed = ephy_window_get_active_embed (window);
 	g_return_if_fail (EPHY_IS_EMBED (embed));
 
-	ephy_embed_set_print_preview_mode (embed, TRUE);
+	info = ephy_print_get_print_info ();
+	info->preview = TRUE;
+
+	ephy_embed_print (embed, info);
+
+	ephy_print_info_free (info);
+
 	ephy_window_set_print_preview (window, TRUE);
 }
 
@@ -98,12 +105,7 @@ void
 window_cmd_file_print (GtkAction *action,
 		       EphyWindow *window)
 {
-	EphyEmbed *embed;
-
-	embed = ephy_window_get_active_embed (window);
-	g_return_if_fail (EPHY_IS_EMBED (embed));
-
-	ephy_embed_print (embed);
+	ephy_window_print (window);
 }
 
 void
@@ -394,7 +396,8 @@ window_cmd_file_open (GtkAction *action,
 	dialog = ephy_file_chooser_new (_("Open"),
 					GTK_WIDGET (window),
 					GTK_FILE_CHOOSER_ACTION_OPEN,
-					CONF_STATE_OPEN_DIR);
+					CONF_STATE_OPEN_DIR,
+					EPHY_FILE_FILTER_ALL_SUPPORTED);
 
 	g_signal_connect (dialog, "response",
 			  G_CALLBACK (open_response_cb), window);
@@ -702,11 +705,6 @@ editor_can_open_uri (char *address)
 		gnome_vfs_uri_unref (uri);
 	}
 
-	if (app)
-	{
-		gnome_vfs_mime_application_free (app);
-	}
-
 	return result;
 }
 
@@ -768,8 +766,6 @@ window_cmd_view_page_source (GtkAction *action,
 	{
 		save_temp_source (embed);
 	}
-
-	g_free (address);
 }
 
 void
@@ -909,7 +905,7 @@ window_cmd_help_about (GtkAction *action,
 	static GtkWidget *about = NULL;
 	GtkWidget** ptr;
 	const char *icon_path;
-	GdkPixbuf *logo = NULL;
+	GdkPixbuf *icon = NULL;
 	GtkIconTheme *icon_theme;
 	GtkIconInfo *icon_info;
 
@@ -924,7 +920,7 @@ window_cmd_help_about (GtkAction *action,
 	char *documenters[] = {
 		"Patanjali Somayaji <patanjali@codito.com>",
 		"David Bordoley <bordoley@msu.edu>",
-		"Piers Cornwell", 
+		"Piers Cornwell <piers@gnome.org>", 
 		NULL
 	};
 
@@ -942,16 +938,14 @@ window_cmd_help_about (GtkAction *action,
 	icon_theme = gtk_icon_theme_get_default ();
 	icon_info = gtk_icon_theme_lookup_icon (icon_theme, "web-browser", -1, 0);
 
-	if (icon_info != NULL)
+	if (icon_info)
 	{
 		icon_path = gtk_icon_info_get_filename (icon_info);
 
 		if (icon_path != NULL)
 		{
-			logo = gdk_pixbuf_new_from_file (icon_path, NULL);
+			icon = gdk_pixbuf_new_from_file (icon_path, NULL);
 		}
-
-		gtk_icon_info_free (icon_info);
 	}
 	else
 	{
@@ -965,13 +959,13 @@ window_cmd_help_about (GtkAction *action,
 		       (const char **)authors,
 		       (const char **)documenters,
 		       strcmp (translator_credits, "translator-credits") != 0 ? translator_credits : NULL,
-		       logo);
+		       icon);
 
-	gtk_window_set_icon (GTK_WINDOW (about), logo);
+	gtk_window_set_icon (GTK_WINDOW (about), icon);
 
-	if (logo != NULL)
+	if (icon != NULL)
 	{
-		g_object_unref (logo);
+		g_object_unref (icon);
 	}
 
 	gtk_window_set_transient_for (GTK_WINDOW (about),
